@@ -22,8 +22,6 @@
 
 #include <regex.h>
 
-G_BEGIN_DECLS
-
 typedef enum
 {
     FILTER_TYPE_REGEX,
@@ -40,10 +38,8 @@ struct Filter
 };
 
 
-Filter  *filter_new (const gchar *exp, gboolean case_sens);
+Filter *filter_new (const gchar *exp, gboolean case_sens, FilterType type);
 void filter_free (Filter *filter);
 gboolean filter_match (Filter *filter, gchar *text);
 
-G_END_DECLS
-
 #endif // __FILTER_H__
