@@ -481,14 +481,13 @@ static void gnome_cmd_connect_dialog_init (GnomeCmdConnectDialog *dialog)
     dialog->priv->type_combo = combo = gtk_combo_box_new_text ();
 
     // Keep this in sync with enum ConnectionMethodID in gnome-cmd-con.h
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("SSH"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("FTP (with login)"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Public FTP"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("SSH"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Windows share"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("WebDAV (HTTP)"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Secure WebDAV (HTTPS)"));
-    // gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Custom location"));
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), CON_FTP);     // CON_FTP --> CON_SSH
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Windows share"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("WebDAV (HTTP)"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Secure WebDAV (HTTPS)"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Custom location"));
     gtk_widget_show (combo);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
     gtk_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
@@ -549,8 +548,7 @@ GnomeCmdConFtp *gnome_cmd_connect_dialog_new (gboolean has_alias)
     else
         gtk_widget_set_sensitive (conndlg->priv->alias_entry, FALSE);
 
-    ConnectionMethodID method = CON_FTP;        // later: CON_SSH
-    gtk_combo_box_set_active (GTK_COMBO_BOX (conndlg->priv->type_combo), method);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (conndlg->priv->type_combo), CON_SSH);
 
     conndlg->priv->use_auth = gnome_cmd_data_get_use_gnome_auth_manager ();
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (conndlg->priv->auth_check), conndlg->priv->use_auth);
@@ -639,23 +637,15 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConFtp *server)
 
         const gchar *alias = conndlg->priv->alias ? conndlg->priv->alias->c_str() : NULL;
         const gchar *host = gnome_vfs_uri_get_host_name (uri);      // do not g_free !!
-        const guint  port = gnome_vfs_uri_get_host_port (uri);
-        const gchar *remote_dir = gnome_vfs_uri_get_path (uri);     // do not g_free !!
-        const gchar *user = gnome_vfs_uri_get_user_name (uri);      // do not g_free !!
-        const gchar *password = gnome_vfs_uri_get_password (uri);   // do not g_free !!
 
-        gnome_cmd_con_ftp_set_alias (server, alias);
-        gnome_cmd_con_ftp_set_host_name (server, host);
-        gnome_cmd_con_ftp_set_host_port (server, port);
-        gnome_cmd_con_ftp_set_remote_dir (server, remote_dir);
-        gnome_cmd_con_ftp_set_user_name (server, user);
-        gnome_cmd_con_ftp_set_pw (server, password);
-
-        // do not set con->alias as it is already done in gnome_cmd_con_ftp_set_alias (alias, ...)
+        gnome_cmd_con_set_alias (con, alias);
         gnome_cmd_con_set_uri (con, conndlg->priv->uri_str);
+        gnome_cmd_con_set_host_name (con, host);
         con->method = (ConnectionMethodID) gtk_combo_box_get_active (GTK_COMBO_BOX (conndlg->priv->type_combo));
         con->gnome_auth = conndlg->priv->use_auth;
 
+        gnome_cmd_con_ftp_set_host_name (server, host);
+
         gnome_vfs_uri_unref (uri);
     }
 
