@@ -279,7 +279,7 @@ void gnome_cmd_con_open (GnomeCmdCon *con)
     if (con->state != CON_STATE_OPEN)
         klass->open (con);
 
-    gtk_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GtkFunction)check_con_open_progress, con);
+    g_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GSourceFunc) check_con_open_progress, con);
 }
 
 
@@ -467,8 +467,10 @@ GnomeVFSResult gnome_cmd_con_get_path_target_type (GnomeCmdCon *con, const gchar
     GnomeCmdPath *path = gnome_cmd_con_create_path (con, path_str);
     GnomeVFSURI *uri = gnome_cmd_con_create_uri (con, path);
     GnomeVFSFileInfo *info = gnome_vfs_file_info_new ();
-    GnomeVFSFileInfoOptions infoOpts = GNOME_VFS_FILE_INFO_DEFAULT;
-    GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, info, infoOpts);
+    GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, info, GNOME_VFS_FILE_INFO_DEFAULT);
+
+    if (res == GNOME_VFS_OK && info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK)         // resolve the symlink to get the real type of it
+        res = gnome_vfs_get_file_info_uri (uri, info, (GnomeVFSFileInfoOptions) (GNOME_VFS_FILE_INFO_DEFAULT | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
 
     if (res == GNOME_VFS_OK)
         *type = info->type;
@@ -590,7 +592,8 @@ string &__gnome_cmd_con_make_uri (string &s, const gchar *method, gboolean use_a
     if (!port.empty())
         s += ':' + port;
 
-    s += folder;
+    if (!folder.empty())
+        s += '/' + folder;
 
     return s;
 }
