@@ -132,7 +132,7 @@ inline gint get_int (const gchar *path, int def)
 
 inline void save_connections (const gchar *fname)
 {
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir (), fname);
     FILE  *fd = fopen (path, "w");
 
     if (fd)
@@ -179,7 +179,7 @@ inline void save_connections (const gchar *fname)
 
 inline void save_devices (const gchar *fname)
 {
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir (), fname);
     FILE *fd = fopen (path, "w");
 
     if (fd)
@@ -187,7 +187,7 @@ inline void save_devices (const gchar *fname)
         for (GList *tmp = gnome_cmd_con_list_get_all_dev (data->priv->con_list); tmp; tmp = tmp->next)
         {
             GnomeCmdConDevice *device = GNOME_CMD_CON_DEVICE (tmp->data);
-            if (device && !gnome_cmd_con_device_get_autovol(device))
+            if (device && !gnome_cmd_con_device_get_autovol (device))
             {
                 gchar *alias = gnome_vfs_escape_string (gnome_cmd_con_device_get_alias (device));
                 gchar *device_fn = (gchar *) gnome_cmd_con_device_get_device_fn (device);
@@ -224,7 +224,7 @@ inline void save_devices (const gchar *fname)
 
 inline void save_fav_apps (const gchar *fname)
 {
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir (), fname);
     FILE *fd = fopen (path, "w");
 
     if (fd)
@@ -268,7 +268,7 @@ inline gboolean load_connections (const gchar *fname)
 {
     guint prev_ftp_cons_no = g_list_length (gnome_cmd_con_list_get_all_ftp (data->priv->con_list));
 
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir (), fname);
     FILE  *fd = fopen (path, "r");
 
     if (fd)
@@ -310,9 +310,10 @@ inline gboolean load_connections (const gchar *fname)
                         else
                         {
                             const gchar *text_uri = a[2].c_str();
-                            GnomeVFSURI *uri = gnome_vfs_uri_new (text_uri);
 
-                            if (!uri)
+                            server = gnome_cmd_con_ftp_new (alias, text_uri);
+
+                            if (!server)
                             {
                                 g_warning ("Invalid URI in the '%s' file", path);
                                 g_warning ("\t... %s", line);
@@ -320,34 +321,7 @@ inline gboolean load_connections (const gchar *fname)
                                 //  ????
                             }
                             else
-                            {
-                                const gchar *scheme = gnome_vfs_uri_get_scheme (uri);       // do not g_free
-                                const gchar *host = gnome_vfs_uri_get_host_name (uri);      // do not g_free
-                                const guint  port = gnome_vfs_uri_get_host_port (uri);
-                                const gchar *remote_dir = gnome_vfs_uri_get_path (uri);     // do not g_free
-                                const gchar *user = gnome_vfs_uri_get_user_name (uri);      // do not g_free
-                                const gchar *password = gnome_vfs_uri_get_password (uri);   // do not g_free
-
-                                server = gnome_cmd_con_ftp_new (alias, host, port, user, password, remote_dir);
-
-                                GnomeCmdCon *con = GNOME_CMD_CON (server);
-
-                                // do not set con->alias as it is already done in gnome_cmd_con_ftp_new (alias, ...)
-                                con->uri = g_strdup (text_uri);
-                                con->method = gnome_vfs_uri_is_local (uri) ? CON_LOCAL :
-                                              g_str_equal (scheme, "ftp") ? (g_str_equal (user, "anonymous") ? CON_ANON_FTP : CON_FTP) :
-                                              g_str_equal (scheme, "sftp") ? CON_SSH :
-                                              g_str_equal (scheme, "dav") ? CON_DAV :
-                                              g_str_equal (scheme, "davs") ? CON_DAVS:
-                                              g_str_equal (scheme, "smb") ? CON_SMB :
-                                                                            CON_URI;
-
-                                con->gnome_auth = !password && con->method!=CON_ANON_FTP;
-
                                 gnome_cmd_con_list_add_ftp (data->priv->con_list, server);
-
-                                gnome_vfs_uri_unref (uri);
-                            }
                         }
 
                         g_free (alias);
@@ -377,21 +351,10 @@ inline gboolean load_connections (const gchar *fname)
                                     pw2 = gnome_vfs_unescape_string (pw, NULL);
 
                                 server = gnome_cmd_con_ftp_new (alias2, host2, port2, user2, pw2, NULL);
+                                // server = gnome_cmd_con_ftp_new (alias2, gnome_cmd_con_make_ftp_uri (host2, port2, NULL, user2, pw2));
 
                                 GnomeCmdCon *con = GNOME_CMD_CON (server);
 
-                                GnomeVFSURI *uri = gnome_vfs_uri_new ("ftp:");
-
-                                gnome_vfs_uri_set_host_name (uri, host2);
-                                gnome_vfs_uri_set_host_port (uri, port2);
-                                if (user2 && *user2)                                // do not set empty user
-                                    gnome_vfs_uri_set_user_name (uri, user2);
-                                if (pw2 && *pw2)                                    // do not set empty password
-                                    gnome_vfs_uri_set_password (uri, pw2);
-
-                                // do not set con->alias as it is already done in gnome_cmd_con_ftp_new (alias, ...)
-                                con->uri = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
-                                con->method = g_str_equal (user2, "anonymous") ? CON_ANON_FTP : CON_FTP;
                                 con->gnome_auth = FALSE;
 
                                 gnome_cmd_con_list_add_ftp (data->priv->con_list, server);
@@ -399,7 +362,6 @@ inline gboolean load_connections (const gchar *fname)
                                 g_free (host2);
                                 g_free (user2);
                                 g_free (pw2);
-                                gnome_vfs_uri_unref (uri);
                             }
 
                             g_free (alias2);
@@ -429,31 +391,17 @@ inline gboolean load_connections (const gchar *fname)
                                 gchar *user2        = gnome_vfs_unescape_string (a[6], NULL);
                                 gchar *password2    = gnome_vfs_unescape_string (a[7], NULL);
 
-                                GnomeCmdConFtp *server = gnome_cmd_con_ftp_new (alias2, host2, port2, user2, password2, remote_dir2);
+                                server = gnome_cmd_con_ftp_new (alias2, host2, port2, user2, password2, remote_dir2);
+                                // server = gnome_cmd_con_ftp_new (alias2, gnome_cmd_con_make_ftp_uri (host2, port2, remote_dir2, user2, password2));
 
                                 GnomeCmdCon *con = GNOME_CMD_CON (server);
 
-                                GnomeVFSURI *uri0 = gnome_vfs_uri_new (scheme2);
-                                GnomeVFSURI *uri1 = gnome_vfs_uri_append_path (uri0, remote_dir2);
-
-                                gnome_vfs_uri_set_host_name (uri1, host2);
-                                gnome_vfs_uri_set_host_port (uri1, port2);
-                                if (user2 && *user2)                                // do not set empty user
-                                    gnome_vfs_uri_set_user_name (uri1, user2);
-                                if (password2 && *password2)                        // do not set empty password
-                                    gnome_vfs_uri_set_password (uri1, password2);
-
-                                // do not set con->alias as it is already done in gnome_cmd_con_ftp_new (alias, ...)
-                                con->uri = gnome_vfs_uri_to_string (uri1, GNOME_VFS_URI_HIDE_NONE);
-                                con->method = g_str_equal (user2, "anonymous") ? CON_ANON_FTP : CON_FTP;
                                 con->gnome_auth = FALSE;
 
                                 g_free (host2);
                                 g_free (remote_dir2);
                                 g_free (user2);
                                 g_free (password2);
-                                gnome_vfs_uri_unref (uri0);
-                                gnome_vfs_uri_unref (uri1);
 
                                 gnome_cmd_con_list_add_ftp (data->priv->con_list, server);
                             }
@@ -505,23 +453,29 @@ inline gboolean load_connections (const gchar *fname)
 
     g_free (path);
 
-    return fd!=NULL && g_list_length(gnome_cmd_con_list_get_all_ftp(data->priv->con_list))>prev_ftp_cons_no;
+    if (!g_list_length (gnome_cmd_con_list_get_all_ftp (data->priv->con_list)))
+    {
+        GnomeCmdConFtp *server = gnome_cmd_con_ftp_new (_("GNOME Commander"), "ftp://anonymous@ftp.gnome.org/pub/GNOME/sources/gnome-commander/");
+        gnome_cmd_con_list_add_ftp (data->priv->con_list, server);
+    }
+
+    return fd!=NULL && g_list_length (gnome_cmd_con_list_get_all_ftp (data->priv->con_list))>prev_ftp_cons_no;
 }
 
 
 inline gboolean vfs_is_uri_local (const char *uri)
 {
-    GnomeVFSURI *pURI = gnome_vfs_uri_new(uri);
+    GnomeVFSURI *pURI = gnome_vfs_uri_new (uri);
 
     if (!pURI)
         return FALSE;
 
-    gboolean b = gnome_vfs_uri_is_local(pURI);
-    gnome_vfs_uri_unref(pURI);
+    gboolean b = gnome_vfs_uri_is_local (pURI);
+    gnome_vfs_uri_unref (pURI);
 
     /* make sure this is actually a local path
            (gnome treats "burn://" as local, too and we don't want that)  */
-    if (g_strncasecmp(uri,"file:/", 6)!=0)
+    if (g_strncasecmp (uri,"file:/", 6)!=0)
         b = FALSE;
 
     DEBUG('m',"uri (%s) is %slocal\n", uri, b?"":"NOT ");
@@ -538,19 +492,19 @@ inline void remove_vfs_volume (GnomeVFSVolume *volume)
         return;
 
     uri = gnome_vfs_volume_get_activation_uri (volume);
-    if (!vfs_is_uri_local(uri))
+    if (!vfs_is_uri_local (uri))
     {
         g_free (uri);
         return;
     }
 
     path = gnome_vfs_volume_get_device_path (volume);
-    localpath = gnome_vfs_get_local_path_from_uri(uri);
+    localpath = gnome_vfs_get_local_path_from_uri (uri);
 
     for (GList *tmp = gnome_cmd_con_list_get_all_dev (data->priv->con_list); tmp; tmp = tmp->next)
     {
         GnomeCmdConDevice *device = GNOME_CMD_CON_DEVICE (tmp->data);
-        if (device && gnome_cmd_con_device_get_autovol(device))
+        if (device && gnome_cmd_con_device_get_autovol (device))
         {
             gchar *device_fn = (gchar *) gnome_cmd_con_device_get_device_fn (device);
             const gchar *mountp = gnome_cmd_con_device_get_mountp (device);
@@ -559,7 +513,7 @@ inline void remove_vfs_volume (GnomeVFSVolume *volume)
             {
                 DEBUG('m',"Remove Volume:\ndevice_fn = %s\tmountp = %s\n",
                 device_fn,mountp);
-                gnome_cmd_con_list_remove_device(data->priv->con_list, device);
+                gnome_cmd_con_list_remove_device (data->priv->con_list, device);
                 break;
             }
         }
@@ -578,7 +532,7 @@ inline gboolean device_mount_point_exists (GnomeCmdConList *list, const gchar *m
     for (GList *tmp = gnome_cmd_con_list_get_all_dev (list); tmp; tmp = tmp->next)
     {
         GnomeCmdConDevice *device = GNOME_CMD_CON_DEVICE (tmp->data);
-        if (device && !gnome_cmd_con_device_get_autovol(device))
+        if (device && !gnome_cmd_con_device_get_autovol (device))
         {
             gchar *mountp = gnome_vfs_escape_string (gnome_cmd_con_device_get_mountp (device));
             gchar *mountp2= gnome_vfs_unescape_string (mountp, NULL);
@@ -604,7 +558,7 @@ inline void add_vfs_volume (GnomeVFSVolume *volume)
 
     char *uri = gnome_vfs_volume_get_activation_uri (volume);
 
-    if (!vfs_is_uri_local(uri))
+    if (!vfs_is_uri_local (uri))
     {
         g_free (uri);
         return;
@@ -635,11 +589,11 @@ inline void add_vfs_volume (GnomeVFSVolume *volume)
     DEBUG('m',"icon = %s (full path = %s)\n", icon, iconpath);
 
     // Don't create a new device connect if one already exists. This can happen if the user manually added the same device in "Options|Devices" menu
-    if (!device_mount_point_exists(data->priv->con_list, localpath))
+    if (!device_mount_point_exists (data->priv->con_list, localpath))
     {
         GnomeCmdConDevice *ConDev = gnome_cmd_con_device_new (name, path?path:NULL, localpath, iconpath);
-        gnome_cmd_con_device_set_autovol(ConDev, TRUE);
-        gnome_cmd_con_device_set_vfs_volume(ConDev, volume);
+        gnome_cmd_con_device_set_autovol (ConDev, TRUE);
+        gnome_cmd_con_device_set_vfs_volume (ConDev, volume);
         gnome_cmd_con_list_add_device (data->priv->con_list,ConDev);
     }
     else
@@ -657,12 +611,12 @@ inline void add_vfs_volume (GnomeVFSVolume *volume)
 #if 0
 inline void add_vfs_drive (GnomeVFSDrive *drive)
 {
-    if (!gnome_vfs_drive_is_user_visible(drive))
+    if (!gnome_vfs_drive_is_user_visible (drive))
         return;
 
     char *uri = gnome_vfs_drive_get_activation_uri (drive);
 
-    if (!vfs_is_uri_local(uri))
+    if (!vfs_is_uri_local (uri))
     {
         g_free (uri);
         return;
@@ -673,13 +627,13 @@ inline void add_vfs_drive (GnomeVFSDrive *drive)
     char *name = gnome_vfs_drive_get_display_name (drive);
     GnomeVFSVolume *volume = gnome_vfs_drive_get_mounted_volume (drive);
 
-    char *localpath = gnome_vfs_get_local_path_from_uri(uri);
+    char *localpath = gnome_vfs_get_local_path_from_uri (uri);
 
     DEBUG('m',"name = %s\tpath = %s\turi = %s\tlocal = %s\n",name,path,uri,localpath);
 
     GnomeCmdConDevice *ConDev = gnome_cmd_con_device_new (name,path,localpath, icon);
 
-    gnome_cmd_con_device_set_autovol(ConDev, TRUE);
+    gnome_cmd_con_device_set_autovol (ConDev, TRUE);
 
     gnome_cmd_con_list_add_device (data->priv->con_list,ConDev);
 
@@ -695,19 +649,19 @@ inline void add_vfs_drive (GnomeVFSDrive *drive)
 
 static void volume_mounted (GnomeVFSVolumeMonitor *volume_monitor, GnomeVFSVolume *volume)
 {
-    add_vfs_volume(volume);
+    add_vfs_volume (volume);
 }
 
 
 static void volume_unmounted (GnomeVFSVolumeMonitor *volume_monitor, GnomeVFSVolume *volume)
 {
-    remove_vfs_volume(volume);
+    remove_vfs_volume (volume);
 }
 
 #if 0
 static void drive_connected (GnomeVFSVolumeMonitor *volume_monitor, GnomeVFSDrive *drive)
 {
-    add_vfs_drive(drive);
+    add_vfs_drive (drive);
 }
 
 static void drive_disconnected (GnomeVFSVolumeMonitor *volume_monitor, GnomeVFSDrive *drive)
@@ -716,7 +670,7 @@ static void drive_disconnected (GnomeVFSVolumeMonitor *volume_monitor, GnomeVFSD
 }
 #endif
 
-inline void set_vfs_volume_monitor()
+inline void set_vfs_volume_monitor ()
 {
     monitor = gnome_vfs_get_volume_monitor ();
 
@@ -729,7 +683,7 @@ inline void set_vfs_volume_monitor()
 }
 
 
-inline void load_vfs_auto_devices()
+inline void load_vfs_auto_devices ()
 {
     GnomeVFSVolumeMonitor *monitor = gnome_vfs_get_volume_monitor ();
     GList *volumes = gnome_vfs_volume_monitor_get_mounted_volumes (monitor);
@@ -755,7 +709,7 @@ inline void load_vfs_auto_devices()
 
 inline void load_devices (const gchar *fname)
 {
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir (), fname);
     FILE *fd = fopen (path, "r");
 
     if (fd)
@@ -796,7 +750,7 @@ inline void load_devices (const gchar *fname)
         if (errno != ENOENT)
             warn_print ("Failed to open the file %s for reading\n", path);
 
-    load_vfs_auto_devices();
+    load_vfs_auto_devices ();
 
     g_free (path);
 }
@@ -805,7 +759,7 @@ inline void load_devices (const gchar *fname)
 inline void load_fav_apps (const gchar *fname)
 {
     data->priv->fav_apps = NULL;
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir (), fname);
     FILE *fd = fopen (path, "r");
     if (fd)
     {
@@ -1551,7 +1505,7 @@ void gnome_cmd_data_load (void)
     load_rename_history ();
     load_auto_load_plugins ();
 
-    set_vfs_volume_monitor();
+    set_vfs_volume_monitor ();
 
     static struct
     {
