@@ -75,6 +75,18 @@ static GnomeCmdCListClass *parent_class = NULL;
 
 static guint file_list_signals[LAST_SIGNAL] = { 0 };
 
+
+typedef struct
+{
+    guint id;
+    const gchar *title;
+    guint default_width;
+    GtkJustification justification;
+    gboolean default_sort_direction;
+    GCompareDataFunc sort_func;
+} GnomeCmdFileListColumn;
+
+
 static gint sort_by_name (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl);
 static gint sort_by_ext (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl);
 static gint sort_by_dir (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl);
@@ -86,7 +98,7 @@ static gint sort_by_group (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList
 
 
 GnomeCmdFileListColumn file_list_column[FILE_LIST_NUM_COLUMNS] =
-{{FILE_LIST_COLUMN_ICON,"",16,GTK_JUSTIFY_CENTER,FILE_LIST_SORT_ASCENDING,NULL},
+{{FILE_LIST_COLUMN_ICON,"",16,GTK_JUSTIFY_CENTER,FILE_LIST_SORT_ASCENDING, NULL},
  {FILE_LIST_COLUMN_NAME, N_("name"), 140, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_ASCENDING, (GCompareDataFunc) sort_by_name},
  {FILE_LIST_COLUMN_EXT, N_("ext"), 40, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_ASCENDING, (GCompareDataFunc) sort_by_ext},
  {FILE_LIST_COLUMN_DIR, N_("dir"), 240, GTK_JUSTIFY_LEFT, FILE_LIST_SORT_ASCENDING, (GCompareDataFunc) sort_by_dir},
@@ -130,6 +142,12 @@ typedef struct
 } FileFormatData;
 
 
+inline char *gnome_cmd_get_collation_fname (GnomeCmdFile *f)
+{
+    return f->collate_key ? f->collate_key : f->info->name;
+}
+
+
 inline int get_num_files (GnomeCmdFileList *fl)
 {
     g_return_val_if_fail (GNOME_CMD_IS_FILE_LIST (fl), -1);
@@ -176,26 +194,27 @@ inline void show_selpat_dialog (GnomeCmdFileList *fl, gboolean mode)
 
 
 // Given a GnomeFileList, returns the upper-left corner of the selected file
-static void get_focus_row_coordinates(GnomeCmdFileList *fl, gint *x, gint *y, gint *width, gint *height)
+static void get_focus_row_coordinates (GnomeCmdFileList *fl, gint &x, gint &y, gint &width, gint &height)
 {
     #define CELL_SPACING 1
     #define COLUMN_INSET 3
 
-    gint ox, oy, row, rowh, colx;
+    gint x0, y0;
 
-    GnomeCmdExtDispMode ext_disp_mode = gnome_cmd_data_get_ext_disp_mode();
+    gdk_window_get_origin (GTK_CLIST (fl)->clist_window, &x0, &y0);
 
-    gdk_window_get_origin (GTK_CLIST(fl)->clist_window, &ox, &oy);
-    row = GTK_CLIST (fl)->focus_row;
-    rowh = GTK_CLIST (fl)->row_height + CELL_SPACING;
-    colx = GTK_CLIST (fl)->column[1].area.x - COLUMN_INSET - CELL_SPACING;
-    *width = GTK_CLIST (fl)->column[1].area.width + COLUMN_INSET * 2;
-    if (ext_disp_mode != GNOME_CMD_EXT_DISP_WITH_FNAME)
-        *width += GTK_CLIST (fl)->column[2].area.width + COLUMN_INSET + CELL_SPACING;
-    *height = rowh + CELL_SPACING * 2;
+    gint row = GTK_CLIST (fl)->focus_row;
+    gint rowh = GTK_CLIST (fl)->row_height + CELL_SPACING;
+    gint colx = GTK_CLIST (fl)->column[FILE_LIST_COLUMN_NAME].area.x - COLUMN_INSET - CELL_SPACING;
 
-    *x = ox + colx;
-    *y = oy + row*rowh + GTK_CLIST (fl)->voffset;
+    x = x0 + colx;
+    y = y0 + row*rowh + GTK_CLIST (fl)->voffset;
+
+    width = GTK_CLIST (fl)->column[FILE_LIST_COLUMN_NAME].area.width + 2*COLUMN_INSET;
+    if (gnome_cmd_data_get_ext_disp_mode () != GNOME_CMD_EXT_DISP_BOTH)
+        width += GTK_CLIST (fl)->column[FILE_LIST_COLUMN_EXT].area.width + 2*COLUMN_INSET + CELL_SPACING;
+
+    height = rowh + 2*CELL_SPACING;
 }
 
 
@@ -228,6 +247,7 @@ static void select_file (GnomeCmdFileList *fl, GnomeCmdFile *finfo)
     if (row == -1)
         return;
 
+
     if (!gnome_cmd_data_get_use_ls_colors ())
         gtk_clist_set_row_style (GTK_CLIST (fl), row, sel_list_style);
     else
@@ -366,7 +386,6 @@ static void toggle_files_with_same_extension (GnomeCmdFileList *fl, gboolean sel
 {
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
 
-    GList *sel;
     const gchar *ext1, *ext2;
 
     GnomeCmdFile *f = gnome_cmd_file_list_get_selected_file (fl);
@@ -374,7 +393,7 @@ static void toggle_files_with_same_extension (GnomeCmdFileList *fl, gboolean sel
     ext1 = gnome_cmd_file_get_extension (f);
     if (!ext1) return;
 
-    sel = g_list_copy (gnome_cmd_file_list_get_selected_files (fl));
+    GList *sel = g_list_copy (gnome_cmd_file_list_get_selected_files (fl));
 
     for (GList *tmp=gnome_cmd_file_list_get_all_files (fl); tmp; tmp = tmp->next)
     {
@@ -427,8 +446,6 @@ inline void toggle_with_pattern (GnomeCmdFileList *fl, const gchar *pattern, gbo
 
 static void create_column_titles (GnomeCmdFileList *fl)
 {
-    gtk_clist_set_column_width (GTK_CLIST (fl), 0, gnome_cmd_data_get_fs_col_width (FILE_LIST_COLUMN_ICON));
-    gtk_clist_set_column_justification (GTK_CLIST (fl), 0, file_list_column[FILE_LIST_COLUMN_ICON].justification);
     gtk_clist_column_title_passive (GTK_CLIST (fl), FILE_LIST_COLUMN_ICON);
 
     for (gint i=FILE_LIST_COLUMN_NAME; i<FILE_LIST_NUM_COLUMNS; i++)
@@ -460,7 +477,7 @@ static void create_column_titles (GnomeCmdFileList *fl)
         gtk_clist_set_column_widget (GTK_CLIST (fl), i, hbox);
     }
 
-    for (gint i=FILE_LIST_COLUMN_NAME; i<FILE_LIST_NUM_COLUMNS; i++)
+    for (gint i=FILE_LIST_COLUMN_ICON; i<FILE_LIST_NUM_COLUMNS; i++)
     {
         gtk_clist_set_column_width (GTK_CLIST (fl), i, gnome_cmd_data_get_fs_col_width (i));
         gtk_clist_set_column_justification (GTK_CLIST (fl), i, file_list_column[i].justification);
@@ -574,13 +591,7 @@ static char *build_selected_file_list (GnomeCmdFileList *fl, int *file_list_len)
 }
 
 
-static void
-drag_data_get (GtkWidget        *widget,
-               GdkDragContext   *context,
-               GtkSelectionData *selection_data,
-               guint            info,
-               guint32          time,
-               GnomeCmdFileList *fl)
+static void drag_data_get (GtkWidget *widget, GdkDragContext *context, GtkSelectionData *selection_data, guint info, guint32 time, GnomeCmdFileList *fl)
 {
     int len;
     GList *files;
@@ -625,11 +636,11 @@ inline void init_dnd (GnomeCmdFileList *fl)
 
 static void popup_position_function (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer user_data)
 {
-    GnomeCmdFileList *fl = GNOME_CMD_FILE_LIST(user_data);
+    GnomeCmdFileList *fl = GNOME_CMD_FILE_LIST (user_data);
 
-    gint w,h;
+    gint w, h;
 
-    get_focus_row_coordinates(fl, x, y, &w, &h);
+    get_focus_row_coordinates (fl, *x, *y, w, h);
 }
 
 
@@ -642,15 +653,15 @@ static void show_file_popup (GnomeCmdFileList *fl, GdkEventButton *event)
     gtk_widget_ref (menu);
     gtk_object_set_data_full (GTK_OBJECT (fl), "file_popup_menu", menu, (GtkDestroyNotify)gtk_widget_unref);
 
-    gnome_popup_menu_do_popup (menu, (GtkMenuPositionFunc)popup_position_function, fl, event, fl, NULL);
+    gnome_popup_menu_do_popup (menu, (GtkMenuPositionFunc) popup_position_function, fl, event, fl, NULL);
 }
 
 
-static void show_file_popup_with_warp (GnomeCmdFileList *fl)
+inline void show_file_popup_with_warp (GnomeCmdFileList *fl)
 {
     gint x, y, w, h;
 
-    get_focus_row_coordinates (fl, &x, &y, &w, &h);
+    get_focus_row_coordinates (fl, x, y, w, h);
 
     //FIXME: Warp the pointer to x, y here
 
@@ -711,8 +722,6 @@ inline gint my_intcmp (gint i1, gint i2, gboolean raising)
 
 static gint sort_by_name (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
 {
-    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
-
     if (strcmp (f1->info->name, "..") == 0)
         return -1;
 
@@ -725,15 +734,14 @@ static gint sort_by_name (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *
     if (f1->info->type < f2->info->type)
         return 1;
 
-    return my_strcmp (f1->info->name, f2->info->name, raising);
+    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
+
+    return my_strcmp (gnome_cmd_get_collation_fname (f1), gnome_cmd_get_collation_fname (f2), raising);
 }
 
 
-static gint
-sort_by_ext (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
+static gint sort_by_ext (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
 {
-    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
-
     if (strcmp (f1->info->name, "..") == 0)
         return -1;
 
@@ -746,8 +754,10 @@ sort_by_ext (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
     if (f1->info->type < f2->info->type)
         return 1;
 
-    if (!gnome_cmd_file_get_extension(f1) && !gnome_cmd_file_get_extension (f2))
-        return my_strcmp (f1->info->name, f2->info->name, fl->priv->sort_raising[1]);
+    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
+
+    if (!gnome_cmd_file_get_extension (f1) && !gnome_cmd_file_get_extension (f2))
+        return my_strcmp (gnome_cmd_get_collation_fname (f1), gnome_cmd_get_collation_fname (f2), fl->priv->sort_raising[1]);
 
     if (!gnome_cmd_file_get_extension (f1))
         return raising?1:-1;
@@ -756,59 +766,61 @@ sort_by_ext (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
 
     gint ret = my_strcmp (gnome_cmd_file_get_extension (f1), gnome_cmd_file_get_extension (f2), raising);
 
-    return ret ? ret : my_strcmp (f1->info->name, f2->info->name, fl->priv->sort_raising[1]);
+    return ret ? ret : my_strcmp (gnome_cmd_get_collation_fname (f1), gnome_cmd_get_collation_fname (f2), fl->priv->sort_raising[1]);
 }
 
 
 static gint sort_by_dir (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
 {
-    gint ret = 0;
-    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
-
-    gchar *t1 = gnome_cmd_file_get_path (f1);
-    gchar *t2 = gnome_cmd_file_get_path (f2);
-    gchar *d1 = g_path_get_dirname (t1);
-    gchar *d2 = g_path_get_dirname (t2);
-
-    if (strcmp (f1->info->name, "..") == 0)
-        ret = -1;
-
-    if (strcmp (f2->info->name, "..") == 0)
-        ret = 1;
-
-    if (f1->info->type > f2->info->type)
-        ret = -1;
-
-    if (f1->info->type < f2->info->type)
-        ret = 1;
-
-    g_free (t1);
-    g_free (t2);
-    g_free (d1);
-    g_free (d2);
-
-    return ret ? ret : my_strcmp (d1, d2, raising);
-}
-
-
-static gint sort_by_size (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
-{
-    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
-    gboolean file_raising = fl->priv->sort_raising[1];
-
     if (strcmp (f1->info->name, "..") == 0)
         return -1;
 
     if (strcmp (f2->info->name, "..") == 0)
         return 1;
 
+    if (f1->info->type > f2->info->type)
+        return -1;
+
+    if (f1->info->type < f2->info->type)
+        return 1;
+
+    // gchar *t1 = gnome_cmd_file_get_path (f1);
+    // gchar *t2 = gnome_cmd_file_get_path (f2);
+    // gchar *d1 = g_path_get_dirname (t1);
+    // gchar *d2 = g_path_get_dirname (t2);
+
+    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
+    // gint ret = my_strcmp (d1, d2, raising);
+
+    // g_free (t1);
+    // g_free (t2);
+    // g_free (d1);
+    // g_free (d2);
+
+    // return ret;
+
+    return my_strcmp (gnome_cmd_get_collation_fname (f1), gnome_cmd_get_collation_fname (f2), raising);
+}
+
+
+static gint sort_by_size (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
+{
+    if (strcmp (f1->info->name, "..") == 0)
+        return -1;
+
+    if (strcmp (f2->info->name, "..") == 0)
+        return 1;
+
+    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
+    gboolean file_raising = fl->priv->sort_raising[1];
+
     gint ret = my_intcmp (f1->info->type, f2->info->type, TRUE);
 
     if (!ret)
     {
         ret = my_intcmp (f1->info->size, f2->info->size, raising);
         if (!ret)
-            ret = my_strcmp (f1->info->name, f2->info->name, file_raising);
+            ret = my_strcmp (gnome_cmd_get_collation_fname (f1), gnome_cmd_get_collation_fname (f2), file_raising);
     }
     return ret;
 }
@@ -816,21 +828,21 @@ static gint sort_by_size (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *
 
 static gint sort_by_perm (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
 {
-    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
-    gboolean file_raising = fl->priv->sort_raising[1];
-
     if (strcmp (f1->info->name, "..") == 0)
         return -1;
 
     if (strcmp (f2->info->name, "..") == 0)
         return 1;
 
+    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
+    gboolean file_raising = fl->priv->sort_raising[1];
+
     gint ret = my_intcmp (f1->info->type, f2->info->type, TRUE);
     if (!ret)
     {
         ret = my_intcmp (f1->info->permissions, f2->info->permissions, raising);
         if (!ret)
-            ret = my_strcmp (f1->info->name, f2->info->name, file_raising);
+            ret = my_strcmp (gnome_cmd_get_collation_fname (f1), gnome_cmd_get_collation_fname (f2), file_raising);
     }
     return ret;
 }
@@ -838,21 +850,21 @@ static gint sort_by_perm (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *
 
 static gint sort_by_date (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
 {
-    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
-    gboolean file_raising = fl->priv->sort_raising[1];
-
     if (strcmp (f1->info->name, "..") == 0)
         return -1;
 
     if (strcmp (f2->info->name, "..") == 0)
         return 1;
 
+    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
+    gboolean file_raising = fl->priv->sort_raising[1];
+
     gint ret = my_intcmp (f1->info->type, f2->info->type, TRUE);
     if (!ret)
     {
         ret = my_intcmp (f1->info->mtime, f2->info->mtime, raising);
         if (!ret)
-            ret = my_strcmp (f1->info->name, f2->info->name, file_raising);
+            ret = my_strcmp (gnome_cmd_get_collation_fname (f1), gnome_cmd_get_collation_fname (f2), file_raising);
     }
     return ret;
 }
@@ -860,21 +872,21 @@ static gint sort_by_date (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *
 
 static gint sort_by_owner (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
 {
-    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
-    gboolean file_raising = fl->priv->sort_raising[1];
-
     if (strcmp (f1->info->name, "..") == 0)
         return -1;
 
     if (strcmp (f2->info->name, "..") == 0)
         return 1;
 
+    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
+    gboolean file_raising = fl->priv->sort_raising[1];
+
     gint ret = my_intcmp (f1->info->type, f2->info->type, TRUE);
     if (!ret)
     {
         ret = my_intcmp (f1->info->uid, f2->info->uid, raising);
         if (!ret)
-            ret = my_strcmp (f1->info->name, f2->info->name, file_raising);
+            ret = my_strcmp (gnome_cmd_get_collation_fname (f1), gnome_cmd_get_collation_fname (f2), file_raising);
     }
     return ret;
 }
@@ -882,21 +894,21 @@ static gint sort_by_owner (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList
 
 static gint sort_by_group (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *fl)
 {
-    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
-    gboolean file_raising = fl->priv->sort_raising[1];
-
     if (strcmp (f1->info->name, "..") == 0)
         return -1;
 
     if (strcmp (f2->info->name, "..") == 0)
         return 1;
 
+    gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
+    gboolean file_raising = fl->priv->sort_raising[1];
+
     gint ret = my_intcmp (f1->info->type, f2->info->type, TRUE);
     if (!ret)
     {
         ret = my_intcmp (f1->info->gid, f2->info->gid, raising);
         if (!ret)
-            ret = my_strcmp (f1->info->name, f2->info->name, file_raising);
+            ret = my_strcmp (gnome_cmd_get_collation_fname (f1), gnome_cmd_get_collation_fname (f2), file_raising);
     }
     return ret;
 }
@@ -924,11 +936,7 @@ static gint sort_by_group (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList
 }
 
 
-static void
-on_scroll_vertical                  (GtkCList        *clist,
-                                     GtkScrollType    scroll_type,
-                                     gfloat           position,
-                                     GnomeCmdFileList *fl)
+static void on_scroll_vertical (GtkCList *clist, GtkScrollType scroll_type, gfloat position, GnomeCmdFileList *fl)
 {
     g_return_if_fail (GTK_IS_CLIST (clist));
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
@@ -1016,66 +1024,71 @@ static gboolean mime_exec_file (GnomeCmdFile *finfo)
 }
 
 
-static void
-on_file_clicked (GnomeCmdFileList *fl,
-                 GnomeCmdFile *finfo, GdkEventButton *event,
-                 gpointer data)
+static void on_file_clicked (GnomeCmdFileList *fl, GnomeCmdFile *finfo, GdkEventButton *event, gpointer data)
 {
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
     g_return_if_fail (finfo != NULL);
     g_return_if_fail (event != NULL);
 
-    gint row = get_row_from_file (fl, finfo);
-
     if (event->type == GDK_2BUTTON_PRESS && event->button == 1)
     {
         mime_exec_file (finfo);
     }
-    else if (event->type == GDK_BUTTON_PRESS && (event->button == 1 || event->button == 3))
-    {
-        gnome_cmd_file_list_select_row (fl, row);
-        gtk_widget_grab_focus (GTK_WIDGET (fl));
+    else
+        if (event->type == GDK_BUTTON_PRESS && (event->button == 1 || event->button == 3))
+        {
+            gint prev_row = fl->priv->cur_file;
+            gint row = get_row_from_file (fl, finfo);
 
-        if (event->button == 1)
-        {
-            if (event->state & GDK_SHIFT_MASK)
-                select_file_range (fl, fl->priv->shift_down_row, row);
-            else if (event->state & GDK_CONTROL_MASK)
-                toggle_file_at_row (fl, row);
-        }
-        else if (event->button == 3)
-        {
-            if (strcmp (finfo->info->name, "..") != 0)
+            gnome_cmd_file_list_select_row (fl, row);
+            gtk_widget_grab_focus (GTK_WIDGET (fl));
+
+            if (event->button == 1)
             {
-                if (gnome_cmd_data_get_right_mouse_button_mode() == RIGHT_BUTTON_SELECTS)
-                {
-                    if (g_list_index (fl->priv->selected_files, finfo) == -1)
-                    {
-                        select_file (fl, finfo);
-                        fl->priv->right_mouse_sel_state = 1;
-                    }
-                    else
-                    {
-                        unselect_file (fl, finfo);
-                        fl->priv->right_mouse_sel_state = 0;
-                    }
-
-                    fl->priv->right_mb_down_file = finfo;
-                    fl->priv->right_mb_timeout_id =
-                        gtk_timeout_add (POPUP_TIMEOUT, (GtkFunction) on_right_mb_timeout, fl);
-                }
+                if (event->state & GDK_SHIFT_MASK)
+                    select_file_range (fl, fl->priv->shift_down_row, row);
                 else
-                    show_file_popup (fl, event);
+                    if (event->state & GDK_CONTROL_MASK)
+                    {
+                        if (!fl->priv->selected_files)
+                        {
+                            if (prev_row!=row)
+                                select_file (fl, get_file_at_row (fl, prev_row));
+                            select_file_at_row (fl, row);
+                        }
+                        else
+                            toggle_file_at_row (fl, row);
+                    }
             }
+            else
+                if (event->button == 3)
+                    if (strcmp (finfo->info->name, "..") != 0)
+                    {
+                        if (gnome_cmd_data_get_right_mouse_button_mode () == RIGHT_BUTTON_SELECTS)
+                        {
+                            if (g_list_index (fl->priv->selected_files, finfo) == -1)
+                            {
+                                select_file (fl, finfo);
+                                fl->priv->right_mouse_sel_state = 1;
+                            }
+                            else
+                            {
+                                unselect_file (fl, finfo);
+                                fl->priv->right_mouse_sel_state = 0;
+                            }
+
+                            fl->priv->right_mb_down_file = finfo;
+                            fl->priv->right_mb_timeout_id =
+                                g_timeout_add (POPUP_TIMEOUT, (GSourceFunc) on_right_mb_timeout, fl);
+                        }
+                        else
+                            show_file_popup (fl, event);
+                    }
         }
-    }
 }
 
 
-static void
-on_motion_notify                     (GtkCList *clist,
-                                      GdkEventMotion *event,
-                                      GnomeCmdFileList *fl)
+static void on_motion_notify (GtkCList *clist, GdkEventMotion *event, GnomeCmdFileList *fl)
 {
     g_return_if_fail (event != NULL);
 
@@ -1223,9 +1236,6 @@ static void class_init (GnomeCmdFileListClass *klass)
 
 static void init (GnomeCmdFileList *fl)
 {
-    gint i;
-    gboolean b;
-
     fl->priv = g_new0 (GnomeCmdFileListPrivate, 1);
     fl->priv->shown_files = gnome_cmd_file_collection_new ();
     // fl->priv->selected_files = NULL;
@@ -1236,17 +1246,20 @@ static void init (GnomeCmdFileList *fl)
     // fl->priv->quicksearch_popup = NULL;
     // fl->priv->focus_later = NULL;
 
-    for (i=0; i<FILE_LIST_NUM_COLUMNS; i++)
-        fl->priv->sort_raising[i] = FALSE;
+    // for (gint i=0; i<FILE_LIST_NUM_COLUMNS; i++)
+        // fl->priv->sort_raising[i] = FALSE;
 
-    gnome_cmd_data_get_sort_params (fl, &i, &b);
-    fl->priv->current_col = i;
-    fl->priv->sort_raising[i] = b;
-    fl->priv->sort_func = file_list_column[i].sort_func;
+    gint col = FILE_LIST_COLUMN_NAME;       // defaults,
+    gboolean b = FILE_LIST_SORT_ASCENDING;  // used when not set by gnome_cmd_data_get_sort_params()
+
+    gnome_cmd_data_get_sort_params (fl, &col, &b);
+    fl->priv->current_col = col;
+    fl->priv->sort_raising[col] = b;
+    fl->priv->sort_func = file_list_column[col].sort_func;
 
     init_dnd (fl);
 
-    for (i=0; i<FILE_LIST_NUM_COLUMNS; i++)
+    for (gint i=0; i<FILE_LIST_NUM_COLUMNS; i++)
         gtk_clist_set_column_resizeable (GTK_CLIST (fl), i, TRUE);
 
     gtk_signal_connect_after (GTK_OBJECT (fl), "scroll_vertical", GTK_SIGNAL_FUNC (on_scroll_vertical), fl);
@@ -1291,7 +1304,7 @@ GtkType gnome_cmd_file_list_get_type (void)
 
 GtkWidget *gnome_cmd_file_list_new ()
 {
-    GnomeCmdFileList *fl = (GnomeCmdFileList *) g_object_new (gnome_cmd_file_list_get_type(), "n_columns", FILE_LIST_NUM_COLUMNS, NULL);
+    GnomeCmdFileList *fl = (GnomeCmdFileList *) g_object_new (gnome_cmd_file_list_get_type (), "n-columns", FILE_LIST_NUM_COLUMNS, NULL);
 
     create_column_titles (fl);
 
@@ -1299,11 +1312,9 @@ GtkWidget *gnome_cmd_file_list_new ()
 }
 
 
-void gnome_cmd_file_list_show_column (GnomeCmdFileList *fl, GnomeCmdFileListColumnID col, gboolean value)
+guint gnome_cmd_file_list_get_column_default_width (GnomeCmdFileListColumnID col)
 {
-    g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
-
-    gtk_clist_set_column_visibility (GTK_CLIST (fl), col, value);
+    return file_list_column[col].default_width;
 }
 
 
@@ -1335,7 +1346,7 @@ inline gchar *strip_extension (const gchar *fname)
 
 inline void format_file_for_display (GnomeCmdFile *finfo, FileFormatData &data, gboolean tree_size)
 {
-    // If the user wants a character insted of icon for filetype set it now
+    // If the user wants a character instead of icon for filetype set it now
     if (gnome_cmd_data_get_layout () == GNOME_CMD_LAYOUT_TEXT)
         data.text[FILE_LIST_COLUMN_ICON] = (gchar *) gnome_cmd_file_get_type_string (finfo);
     else
@@ -1348,7 +1359,7 @@ inline void format_file_for_display (GnomeCmdFile *finfo, FileFormatData &data,
     g_free (t1);
     g_free (t2);
 
-    if (gnome_cmd_data_get_ext_disp_mode() == GNOME_CMD_EXT_DISP_STRIPPED
+    if (gnome_cmd_data_get_ext_disp_mode () == GNOME_CMD_EXT_DISP_STRIPPED
         && finfo->info->type == GNOME_VFS_FILE_TYPE_REGULAR)
     {
         gchar *t = strip_extension (gnome_cmd_file_get_name (finfo));
@@ -1358,7 +1369,7 @@ inline void format_file_for_display (GnomeCmdFile *finfo, FileFormatData &data,
     else
         data.fname = get_utf8 (gnome_cmd_file_get_name (finfo));
 
-    if (gnome_cmd_data_get_ext_disp_mode() != GNOME_CMD_EXT_DISP_WITH_FNAME)
+    if (gnome_cmd_data_get_ext_disp_mode () != GNOME_CMD_EXT_DISP_WITH_FNAME)
         data.fext = get_utf8 (gnome_cmd_file_get_extension (finfo));
     else
         data.fext = NULL;
@@ -1430,27 +1441,23 @@ inline void add_file_to_clist (GnomeCmdFileList *fl, GnomeCmdFile *finfo, gint i
 
 /******************************************************************************
 *
-*   Function: gnome_cmd_file_list_add_file
+*   Function: gnome_cmd_file_list_append_file
 *
 *   Purpose:  Add a file to the list
 *
 *   Params:   @fl: The FileList to add the file to
 *             @finfo: The file to add
-*             @in_row: The row to add the file at. Set to -1 to append the file at the end.
 *
 *   Returns:
 *
 *   Statuses:
 *
 ******************************************************************************/
-void gnome_cmd_file_list_add_file (GnomeCmdFileList *fl, GnomeCmdFile *finfo, gint row)
+void gnome_cmd_file_list_append_file (GnomeCmdFileList *fl, GnomeCmdFile *finfo)
 {
-    /* Add the file to the list
-     *
-     */
     gnome_cmd_file_collection_add (fl->priv->shown_files, finfo);
 
-    add_file_to_clist (fl, finfo, row);
+    add_file_to_clist (fl, finfo, -1);
 }
 
 
@@ -1488,7 +1495,7 @@ void gnome_cmd_file_list_show_files (GnomeCmdFileList *fl, GList *files, gboolea
 
     gtk_clist_freeze (GTK_CLIST (fl));
     for (; tmp; tmp = tmp->next)
-        gnome_cmd_file_list_add_file (fl, GNOME_CMD_FILE (tmp->data), -1);
+        gnome_cmd_file_list_append_file (fl, GNOME_CMD_FILE (tmp->data));
     gtk_clist_thaw (GTK_CLIST (fl));
 
     if (list)
@@ -1505,13 +1512,18 @@ void gnome_cmd_file_list_insert_file (GnomeCmdFileList *fl, GnomeCmdFile *finfo)
         GnomeCmdFile *finfo2 = get_file_at_row (fl, i);
         if (fl->priv->sort_func (finfo2, finfo, fl) == 1)
         {
-            gnome_cmd_file_list_add_file (fl, finfo, i);
+            gnome_cmd_file_collection_add (fl->priv->shown_files, finfo);
+            add_file_to_clist (fl, finfo, i);
+
+            if (i<=fl->priv->cur_file)
+                fl->priv->cur_file++;
+
             return;
         }
     }
 
     // Insert the file at the end of the list
-    gnome_cmd_file_list_add_file (fl, finfo, -1);
+    gnome_cmd_file_list_append_file (fl, finfo);
 }
 
 
@@ -1568,7 +1580,7 @@ void gnome_cmd_file_list_remove_file (GnomeCmdFileList *fl, GnomeCmdFile *finfo)
         fl->priv->selected_files = g_list_remove (fl->priv->selected_files, finfo);
         gnome_cmd_file_collection_remove (fl->priv->shown_files, finfo);
 
-        focus_file_at_row (fl, MIN (row, GTK_CLIST(fl)->focus_row));
+        focus_file_at_row (fl, MIN (row, GTK_CLIST (fl)->focus_row));
     }
 }
 
@@ -1585,13 +1597,6 @@ void gnome_cmd_file_list_remove_file_by_uri (GnomeCmdFileList *fl, const gchar *
 }
 
 
-void gnome_cmd_file_list_remove_files (GnomeCmdFileList *fl, GList *files)
-{
-    for (; files; files = files->next)
-        gnome_cmd_file_list_remove_file (fl, (GnomeCmdFile *) files->data);
-}
-
-
 void gnome_cmd_file_list_remove_all_files (GnomeCmdFileList *fl)
 {
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
@@ -1899,9 +1904,9 @@ void gnome_cmd_file_list_restore_selection (GnomeCmdFileList *fl)
 }
 
 
-static gint compare_filename(GnomeCmdFile *f1, GnomeCmdFile *f2)
+static gint compare_filename (GnomeCmdFile *f1, GnomeCmdFile *f2)
 {
-    return strcmp(f1->info->name, f2->info->name);
+    return strcmp (f1->info->name, f2->info->name);
 }
 
 
@@ -1917,11 +1922,11 @@ void gnome_cmd_file_list_compare_directories (void)
     gnome_cmd_file_list_unselect_all (fl1);
     gnome_cmd_file_list_select_all (fl2);
 
-    for (GList *i=gnome_cmd_file_list_get_all_files(fl1); i; i=i->next)
+    for (GList *i=gnome_cmd_file_list_get_all_files (fl1); i; i=i->next)
     {
         GnomeCmdFile *f1 = (GnomeCmdFile *) i->data;
         GnomeCmdFile *f2;
-        GList *gl2 = g_list_find_custom (fl2->priv->selected_files, f1, (GCompareFunc)compare_filename);
+        GList *gl2 = g_list_find_custom (fl2->priv->selected_files, f1, (GCompareFunc) compare_filename);
 
         if (!gl2)
         {
@@ -2006,7 +2011,7 @@ void gnome_cmd_file_list_show_rename_dialog (GnomeCmdFileList *fl)
     {
         gint x, y, w, h;
 
-        get_focus_row_coordinates (fl, &x, &y, &w, &h);
+        get_focus_row_coordinates (fl, x, y, w, h);
 
         GtkWidget *dialog = gnome_cmd_rename_dialog_new (finfo, x, y, w, h);
 
@@ -2072,7 +2077,7 @@ void gnome_cmd_file_list_show_advrename_dialog (GnomeCmdFileList *fl)
 
     if (files)
     {
-        GtkWidget *dialog = gnome_cmd_advrename_dialog_new (files);
+        GtkWidget *dialog = gnome_cmd_advrename_dialog_new (gnome_cmd_file_list_sort_selection (files, fl));
 
         gtk_widget_ref (dialog);
         gtk_widget_show (dialog);
@@ -2134,7 +2139,7 @@ void gnome_cmd_file_list_view (GnomeCmdFileList *fl, gint internal_viewer)
     if (!finfo)  return;
 
     if (finfo->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
-        create_error_dialog(_("Not an ordinary file: %s"), finfo->info->name);
+        create_error_dialog (_("Not an ordinary file: %s"), finfo->info->name);
     else
         gnome_cmd_file_view (finfo, internal_viewer!=-1 ? internal_viewer :
                                                           gnome_cmd_data_get_use_internal_viewer ());
@@ -2150,7 +2155,7 @@ void gnome_cmd_file_list_edit (GnomeCmdFileList *fl)
     if (!finfo)  return;
 
     if (finfo->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
-        create_error_dialog(_("Not an ordinary file: %s"), finfo->info->name);
+        create_error_dialog (_("Not an ordinary file: %s"), finfo->info->name);
     else
         gnome_cmd_file_edit (finfo);
 }
@@ -2158,9 +2163,9 @@ void gnome_cmd_file_list_edit (GnomeCmdFileList *fl)
 
 gboolean gnome_cmd_file_list_quicksearch_shown (GnomeCmdFileList *fl)
 {
-    g_return_val_if_fail(fl!=NULL,FALSE);
-    g_return_val_if_fail(GNOME_CMD_IS_FILE_LIST(fl),FALSE);
-    g_return_val_if_fail(fl->priv!=NULL,FALSE);
+    g_return_val_if_fail (fl!=NULL,FALSE);
+    g_return_val_if_fail (GNOME_CMD_IS_FILE_LIST (fl),FALSE);
+    g_return_val_if_fail (fl->priv!=NULL,FALSE);
 
     return fl->priv->quicksearch_popup!=NULL;
 }
