@@ -89,33 +89,6 @@ static guint file_selector_signals[LAST_SIGNAL] = { 0 };
  *******************************/
 
 
-void gnome_cmd_file_selector_set_same_directory (GnomeCmdMainWin *mw, FileSelectorID fsID, FileSelectorID otherID)
-{
-    g_return_if_fail (mw!=NULL);
-    g_return_if_fail (mw->priv!=NULL);
-
-    GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (mw, fsID);
-    GnomeCmdFileSelector *other = gnome_cmd_main_win_get_fs (mw, !fsID);
-
-    gboolean fs_is_active = fs->priv->active;
-
-    if (fs_is_active)
-        gnome_cmd_file_selector_set_directory (fs, gnome_cmd_file_selector_get_directory (other));
-    else
-    {
-        GnomeCmdFile *file = gnome_cmd_file_list_get_selected_file (other->list);
-
-        if (file && file->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
-            gnome_cmd_file_selector_goto_directory (fs, gnome_cmd_file_get_real_path (file));
-        else
-            gnome_cmd_file_selector_set_directory (fs, gnome_cmd_file_selector_get_directory (other));
-    }
-
-    gnome_cmd_file_selector_set_active (other, !fs_is_active);
-    gnome_cmd_file_selector_set_active (fs, fs_is_active);
-}
-
-
 inline void show_list_popup (GnomeCmdFileSelector *fs)
 {
     // create the popup menu
@@ -242,20 +215,25 @@ inline void show_dir_tree_sizes (GnomeCmdFileSelector *fs)
 
 inline void set_connection (GnomeCmdFileSelector *fs, GnomeCmdCon *con, GnomeCmdDir *dir=NULL)
 {
-    fs->priv->con = con;
-    fs->priv->dir_history = gnome_cmd_con_get_dir_history (con);
+    gboolean con_change_needed = fs->priv->con==con;
 
-    if (fs->priv->lwd)
+    if (!con_change_needed)
     {
-        gnome_cmd_dir_cancel_monitoring (fs->priv->lwd);
-        gnome_cmd_dir_unref (fs->priv->lwd);
-        fs->priv->lwd = NULL;
-    }
-    if (fs->priv->cwd)
-    {
-        gnome_cmd_dir_cancel_monitoring (fs->priv->cwd);
-        gnome_cmd_dir_unref (fs->priv->cwd);
-        fs->priv->cwd = NULL;
+        fs->priv->con = con;
+        fs->priv->dir_history = gnome_cmd_con_get_dir_history (con);
+
+        if (fs->priv->lwd)
+        {
+            gnome_cmd_dir_cancel_monitoring (fs->priv->lwd);
+            gnome_cmd_dir_unref (fs->priv->lwd);
+            fs->priv->lwd = NULL;
+        }
+        if (fs->priv->cwd)
+        {
+            gnome_cmd_dir_cancel_monitoring (fs->priv->cwd);
+            gnome_cmd_dir_unref (fs->priv->cwd);
+            fs->priv->cwd = NULL;
+        }
     }
 
     if (!dir)
@@ -264,7 +242,8 @@ inline void set_connection (GnomeCmdFileSelector *fs, GnomeCmdCon *con, GnomeCmd
 
     gnome_cmd_file_selector_set_directory (fs, dir);
 
-    gnome_cmd_combo_select_data (GNOME_CMD_COMBO (fs->con_combo), con);
+    if (!con_change_needed)
+        gnome_cmd_combo_select_data (GNOME_CMD_COMBO (fs->con_combo), con);
 }
 
 
@@ -881,6 +860,7 @@ static void on_dir_file_changed (GnomeCmdDir *dir, GnomeCmdFile *finfo, GnomeCmd
 
     if (file_is_in_list (fs, finfo))
     {
+        gnome_cmd_file_invalidate_metadata (finfo);
         gnome_cmd_file_list_update_file (GNOME_CMD_FILE_LIST (fs->list), finfo);
         update_selected_files_label (fs);
     }
@@ -895,6 +875,7 @@ static void on_dir_file_renamed (GnomeCmdDir *dir, GnomeCmdFile *finfo, GnomeCmd
 
     if (file_is_in_list (fs, finfo))
     {
+        // gnome_cmd_file_invalidate_metadata (finfo, TAG_FILE);
         gnome_cmd_file_list_update_file (GNOME_CMD_FILE_LIST (fs->list), finfo);
 
         GnomeCmdFileListColumnID sort_col = gnome_cmd_file_list_get_sort_column (GNOME_CMD_FILE_LIST (fs->list));
@@ -1767,6 +1748,31 @@ void gnome_cmd_file_selector_set_connection (GnomeCmdFileSelector *fs, GnomeCmdC
 }
 
 
+void gnome_cmd_file_selector_set_directory_to_opposite (GnomeCmdMainWin *mw, FileSelectorID fsID)
+{
+    g_return_if_fail (mw!=NULL);
+
+    GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (mw, fsID);
+    GnomeCmdFileSelector *other = gnome_cmd_main_win_get_fs (mw, !fsID);
+
+    GnomeCmdDir *dir = gnome_cmd_file_selector_get_directory (other);
+    gboolean fs_is_active = fs->priv->active;
+
+    if (!fs_is_active)
+    {
+        GnomeCmdFile *file = gnome_cmd_file_list_get_selected_file (other->list);
+
+        if (file && file->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+            dir = gnome_cmd_dir_new_from_info (file->info, dir);
+    }
+
+    set_connection (fs, other->priv->con, dir);
+
+    gnome_cmd_file_selector_set_active (other, !fs_is_active);
+    gnome_cmd_file_selector_set_active (fs, fs_is_active);
+}
+
+
 void gnome_cmd_file_selector_update_connections (GnomeCmdFileSelector *fs)
 {
     g_return_if_fail (GNOME_CMD_IS_FILE_SELECTOR (fs));
@@ -1831,6 +1837,11 @@ GnomeCmdCon *gnome_cmd_file_selector_get_connection (GnomeCmdFileSelector *fs)
 }
 
 
+gboolean gnome_cmd_file_selector_is_local (FileSelectorID fsID)
+{
+    return gnome_cmd_file_selector_is_local (gnome_cmd_main_win_get_fs (main_win, fsID));
+}
+
 void gnome_cmd_file_selector_update_style (GnomeCmdFileSelector *fs)
 {
     g_return_if_fail (GNOME_CMD_IS_FILE_SELECTOR (fs));
