@@ -19,8 +19,6 @@
 #ifndef __GNOME_CMD_PATH_H__
 #define __GNOME_CMD_PATH_H__
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_PATH(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_path_get_type (), GnomeCmdPath)
 #define GNOME_CMD_PATH_CLASS(klass) \
@@ -43,7 +41,7 @@ struct _GnomeCmdPathClass
 {
     GtkObjectClass parent_class;
 
-    /* virtual functions */
+    // virtual functions
     const gchar *(* get_path)          (GnomeCmdPath *path);
     const gchar *(* get_display_path)  (GnomeCmdPath *path);
     GnomeCmdPath *(* get_parent)       (GnomeCmdPath *path);
@@ -51,21 +49,14 @@ struct _GnomeCmdPathClass
 };
 
 
-GtkType
-gnome_cmd_path_get_type (void);
+GtkType gnome_cmd_path_get_type (void);
 
-const gchar *
-gnome_cmd_path_get_path (GnomeCmdPath *path);
+const gchar *gnome_cmd_path_get_path (GnomeCmdPath *path);
 
-const gchar *
-gnome_cmd_path_get_display_path (GnomeCmdPath *path);
+const gchar *gnome_cmd_path_get_display_path (GnomeCmdPath *path);
 
-GnomeCmdPath *
-gnome_cmd_path_get_parent (GnomeCmdPath *path);
+GnomeCmdPath *gnome_cmd_path_get_parent (GnomeCmdPath *path);
 
-GnomeCmdPath *
-gnome_cmd_path_get_child (GnomeCmdPath *path, const gchar *child);
-
-G_END_DECLS
+GnomeCmdPath *gnome_cmd_path_get_child (GnomeCmdPath *path, const gchar *child);
 
 #endif // __GNOME_CMD_PATH_H__
