@@ -39,6 +39,8 @@ static char *msgs[] = {N_("Search _recursively:"),
                        N_("_Unlimited depth"),
                        N_("Current _directory only"),
                        N_("_Limited depth"),
+                       N_("She_ll syntax"),
+                       N_("Rege_x syntax"),
 //                       N_("Search local directories only"),
                        N_("Files _not containing text")};
 #endif
@@ -385,8 +387,8 @@ static gboolean update_search_status_widgets (SearchData *data)
 
     // Add all files found since last update to the list
     for (GList *files = data->pdata.files; files; files = files->next)
-        gnome_cmd_file_list_add_file (GNOME_CMD_FILE_LIST (data->dialog->priv->result_list),
-                                      GNOME_CMD_FILE (files->data), -1);
+        gnome_cmd_file_list_append_file (GNOME_CMD_FILE_LIST (data->dialog->priv->result_list),
+                                      GNOME_CMD_FILE (files->data));
     if (data->pdata.files)
     {
         g_list_free (data->pdata.files);
@@ -540,7 +542,11 @@ static gboolean start_search (GnomeCmdSearchDialog *dialog)
     gtk_widget_set_sensitive (data->dialog->priv->stop_button, TRUE);
 
     // create an re for filename matching
-    data->name_filter = filter_new (data->name_pattern, data->case_sens, gnome_cmd_data_get_filter_type ());
+    GtkWidget *regex_radio = lookup_widget (GTK_WIDGET (dialog), "regex_radio");
+
+    data->name_filter = filter_new (data->name_pattern, data->case_sens,
+                                    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (regex_radio)) ? FILTER_TYPE_REGEX
+                                                                                                   : FILTER_TYPE_FNMATCH);
 
     // if we're going to search through file content create an re for that too
     if (data->content_search)
@@ -622,7 +628,7 @@ static void on_stop (GtkButton *button, GnomeCmdSearchDialog *dialog)
 
 
 /**
- * The user has clicked on the goto button
+ * The user has clicked on the go to button
  *
  */
 static void on_goto (GtkButton *button, GnomeCmdSearchDialog *dialog)
@@ -730,8 +736,7 @@ static void class_init (GnomeCmdSearchDialogClass *klass)
 }
 
 /*
- * create a label with keyboard shortcut and a widget to activate
- * if shortcut is pressed.
+ * create a label with keyboard shortcut and a widget to activate if shortcut is pressed.
  */
 inline GtkWidget *create_label_with_mnemonic (GtkWidget *parent, const gchar *text, GtkWidget *for_widget)
 {
@@ -763,8 +768,21 @@ inline GtkWidget *create_check_with_mnemonic (GtkWidget *parent, gchar *text, gc
 }
 
 /*
- * create a gtk_combo_box_entry_new_text.
- * gtk_combo is deprecated.
+ * create a GtkRadioButton with keyboard shortcut
+ */
+inline GtkWidget *create_radio_with_mnemonic (GtkWidget *parent, GSList *group, gchar *text, gchar *name)
+{
+    GtkWidget *radio = gtk_radio_button_new_with_mnemonic (group, text);
+
+    gtk_widget_ref (radio);
+    gtk_object_set_data_full (GTK_OBJECT (parent), name, radio, (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show (radio);
+
+    return radio;
+}
+
+/*
+ * create a gtk_combo_box_entry_new_text. gtk_combo is deprecated.
  */
 inline GtkWidget *create_combo_box_entry (GtkWidget *parent)
 {
@@ -776,8 +794,7 @@ inline GtkWidget *create_combo_box_entry (GtkWidget *parent)
 }
 
 /*
- * callback function for 'g_list_foreach' to add default value
- * to dropdownbox
+ * callback function for 'g_list_foreach' to add default value to dropdownbox
  */
 static void combo_box_insert_text (gpointer  data, gpointer  user_data)
 {
@@ -787,14 +804,16 @@ static void combo_box_insert_text (gpointer  data, gpointer  user_data)
 
 static void init (GnomeCmdSearchDialog *dialog)
 {
+    SearchDefaults *defaults = gnome_cmd_data_get_search_defaults ();
+
     GtkWidget *window;
-    GtkWidget *vbox1;
+    GtkWidget *vbox;
+    GtkWidget *hbox;
     GtkWidget *table;
     GtkWidget *label;
     GtkWidget *sw;
+    GtkWidget *radio;
     GtkWidget *pbar;
-    SearchDefaults *defaults = gnome_cmd_data_get_search_defaults ();
-
 
     dialog->priv = g_new0 (GnomeCmdSearchDialogPrivate, 1);
     dialog->priv->data = g_new0 (SearchData, 1);
@@ -805,13 +824,13 @@ static void init (GnomeCmdSearchDialog *dialog)
     gnome_cmd_dialog_set_resizable (GNOME_CMD_DIALOG (dialog), TRUE);
     gtk_window_set_default_size (GTK_WINDOW (window), defaults->width, defaults->height);
 
-    vbox1 = create_vbox (window, FALSE, 0);
-    gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), vbox1);
+    vbox = create_vbox (window, FALSE, 0);
+    gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), vbox);
 
     table = create_table (window, 5, 2);
     gtk_table_set_row_spacings (GTK_TABLE (table), 6);
     gtk_table_set_col_spacings (GTK_TABLE (table), 6);
-    gtk_box_pack_start (GTK_BOX (vbox1), table, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, TRUE, 0);
 
     // Search for
     dialog->priv->pattern_combo = create_combo_box_entry (window);
@@ -820,7 +839,7 @@ static void init (GnomeCmdSearchDialog *dialog)
 
     table_add (table, dialog->priv->pattern_combo, 1, 0, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
     if (defaults->name_patterns)
-      g_list_foreach (defaults->name_patterns, combo_box_insert_text, dialog->priv->pattern_combo);
+        g_list_foreach (defaults->name_patterns, combo_box_insert_text, dialog->priv->pattern_combo);
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->pattern_combo), 0);
     gnome_cmd_dialog_editable_enters (GNOME_CMD_DIALOG (dialog), GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (dialog->priv->pattern_combo))));
@@ -836,40 +855,54 @@ static void init (GnomeCmdSearchDialog *dialog)
             GTK_COMBO (gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (dialog->priv->dir_browser))),
             defaults->directories);
 
-    dialog->priv->dir_entry =
-        gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (dialog->priv->dir_browser));
+    dialog->priv->dir_entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (dialog->priv->dir_browser));
+
+
+    hbox = create_hbox (window, FALSE, 0);
+
+    // Recurse check
+    dialog->priv->recurse_check = create_check_with_mnemonic (window, _("Search _recursively"), "recurse_check");
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->recurse_check), defaults->recursive);
+
+
+    // Filename matching
+    gtk_box_pack_start (GTK_BOX (hbox), dialog->priv->recurse_check, FALSE, TRUE, 0);
+
+    radio = create_radio_with_mnemonic (window, NULL, _("She_ll syntax"), "shell_radio");
+    gtk_container_add (GTK_CONTAINER (hbox), radio);
+    if (gnome_cmd_data_get_filter_type () == FILTER_TYPE_FNMATCH)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
+    radio = create_radio_with_mnemonic (window, get_radio_group (radio), _("Rege_x syntax"), "regex_radio");
+    gtk_container_add (GTK_CONTAINER (hbox), radio);
+    if (gnome_cmd_data_get_filter_type () == FILTER_TYPE_REGEX)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
+
+    table_add (table, hbox, 1, 2, GTK_FILL);
+
 
     // Find text
     dialog->priv->find_text_check = create_check_with_mnemonic (window, _("Find _text: "), "find_text");
-    table_add (table, dialog->priv->find_text_check, 0, 2, GTK_FILL);
+    table_add (table, dialog->priv->find_text_check, 0, 3, GTK_FILL);
 
     dialog->priv->find_text_combo = create_combo_box_entry (window);
-    table_add (table, dialog->priv->find_text_combo, 1, 2, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
+    table_add (table, dialog->priv->find_text_combo, 1, 3, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
     gtk_widget_set_sensitive (dialog->priv->find_text_combo, FALSE);
     if (defaults->content_patterns)
-      g_list_foreach (defaults->content_patterns, combo_box_insert_text, dialog->priv->find_text_combo);
+        g_list_foreach (defaults->content_patterns, combo_box_insert_text, dialog->priv->find_text_combo);
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->find_text_combo), 0);
     gnome_cmd_dialog_editable_enters (GNOME_CMD_DIALOG (dialog), GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (dialog->priv->find_text_combo))));
 
-
-    // Recurse check
-    dialog->priv->recurse_check = create_check_with_mnemonic (window, _("Search _recursively"), "recurse_check");
-    gtk_table_attach (GTK_TABLE (table), dialog->priv->recurse_check, 0, 2, 3, 4,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->recurse_check), defaults->recursive);
-
     // Case check
-    dialog->priv->case_check = create_check_with_mnemonic (window, _("_Case sensitive"), "case_check");
-    gtk_table_attach (GTK_TABLE (table), dialog->priv->case_check, 0, 2, 4, 5,
+    dialog->priv->case_check = create_check_with_mnemonic (window, _("Case sensiti_ve"), "case_check");
+    gtk_table_attach (GTK_TABLE (table), dialog->priv->case_check, 1, 2, 4, 5,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->case_check), defaults->case_sens);
 
     dialog->priv->help_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_HELP, GTK_SIGNAL_FUNC (on_help), dialog);
     dialog->priv->close_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_SIGNAL_FUNC (on_close), dialog);
-    dialog->priv->goto_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_Goto"), GTK_SIGNAL_FUNC (on_goto), dialog);
+    dialog->priv->goto_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), _("_Go to"), GTK_SIGNAL_FUNC (on_goto), dialog);
     dialog->priv->stop_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_STOP, GTK_SIGNAL_FUNC (on_stop), dialog);
     dialog->priv->search_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_FIND, GTK_SIGNAL_FUNC (on_search), dialog);
 
@@ -881,7 +914,7 @@ static void init (GnomeCmdSearchDialog *dialog)
     gtk_widget_ref (sw);
     gtk_object_set_data_full (GTK_OBJECT (window), "sw", sw, (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (sw);
-    gtk_box_pack_start (GTK_BOX (vbox1), sw, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), sw, TRUE, TRUE, 0);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
     dialog->priv->result_list = gnome_cmd_file_list_new ();
@@ -901,7 +934,7 @@ static void init (GnomeCmdSearchDialog *dialog)
     gtk_object_set_data_full (GTK_OBJECT (window), "statusbar", dialog->priv->statusbar,
                               (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (dialog->priv->statusbar);
-    gtk_box_pack_start (GTK_BOX (vbox1), dialog->priv->statusbar, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->statusbar, FALSE, TRUE, 0);
 
     pbar = create_progress_bar (window);
     gtk_widget_hide (pbar);
