@@ -14,12 +14,12 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __GNOME_CMD_XFER_PROGRESS_WIN_H__
 #define __GNOME_CMD_XFER_PROGRESS_WIN_H__
 
-
 #define GNOME_CMD_XFER_PROGRESS_WIN(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_xfer_progress_win_get_type (), GnomeCmdXferProgressWin)
 #define GNOME_CMD_XFER_PROGRESS_WIN_CLASS(klass) \
@@ -38,6 +38,7 @@ struct _GnomeCmdXferProgressWin
     GtkWindow parent;
 
     GtkWidget *totalprog;
+    GtkWidget *fileprog;
     GtkWidget *msg_label;
     GtkWidget *fileprog_label;
 
@@ -51,25 +52,18 @@ struct _GnomeCmdXferProgressWinClass
 };
 
 
-GtkWidget*
-gnome_cmd_xfer_progress_win_new (void);
+GtkWidget *gnome_cmd_xfer_progress_win_new (guint no_of_files=0);
 
-GtkType
-gnome_cmd_xfer_progress_win_get_type (void);
+GtkType gnome_cmd_xfer_progress_win_get_type (void);
 
-void
-gnome_cmd_xfer_progress_win_set_total_progress (GnomeCmdXferProgressWin *win,
-                                                GnomeVFSFileSize bytes_copied,
-                                                GnomeVFSFileSize bytes_total);
+void gnome_cmd_xfer_progress_win_set_total_progress (GnomeCmdXferProgressWin *win,
+                                                     GnomeVFSFileSize file_bytes_copied,
+                                                     GnomeVFSFileSize file_size,
+                                                     GnomeVFSFileSize bytes_copied,
+                                                     GnomeVFSFileSize bytes_total);
 
-void
-gnome_cmd_xfer_progress_win_set_msg (GnomeCmdXferProgressWin *win,
-                                     const gchar *string);
+void gnome_cmd_xfer_progress_win_set_msg (GnomeCmdXferProgressWin *win, const gchar *string);
 
-void
-gnome_cmd_xfer_progress_win_set_action (GnomeCmdXferProgressWin *win,
-                                        const gchar *string);
+void gnome_cmd_xfer_progress_win_set_action (GnomeCmdXferProgressWin *win, const gchar *string);
 
-
-
-#endif //__GNOME_CMD_XFER_PROGRESS_WIN_H__
+#endif // __GNOME_CMD_XFER_PROGRESS_WIN_H__
