@@ -60,9 +60,9 @@ typedef struct
     gboolean first_time;
     gchar *cur_file_name;
 
-    GnomeVFSFileSize bytes_total;
     GnomeVFSFileSize file_size;
     GnomeVFSFileSize bytes_copied;
+    GnomeVFSFileSize bytes_total;
     GnomeVFSFileSize total_bytes_copied;
 
     GFunc on_completed_func;
@@ -125,17 +125,13 @@ create_xfer_data (GnomeVFSXferOptions xferOptions, GList *src_uri_list, GList *d
 }
 
 
-static gint
-xfer_callback (GnomeVFSXferProgressInfo *info, gpointer user_data)
+static gint xfer_callback (GnomeVFSXferProgressInfo *info, gpointer user_data)
 {
     return 1;
 }
 
 
-static gint
-async_xfer_callback (GnomeVFSAsyncHandle *handle,
-                     GnomeVFSXferProgressInfo *info,
-                     XferData *data)
+static gint async_xfer_callback (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgressInfo *info, XferData *data)
 {
     data->cur_phase = info->phase;
     data->cur_file = info->file_index;
@@ -162,7 +158,8 @@ async_xfer_callback (GnomeVFSAsyncHandle *handle,
 
     if (info->status == GNOME_VFS_XFER_PROGRESS_STATUS_OVERWRITE)
     {
-        gchar *t = gnome_vfs_get_local_path_from_uri (info->target_name);
+        gchar *t = gnome_cmd_dir_is_local (data->to_dir) ? gnome_vfs_get_local_path_from_uri (info->target_name) :
+                                                           str_uri_basename (info->target_name);
         gchar *fn = get_utf8 (t);
         gchar *msg = g_strdup_printf (_("The file \"%s\" already exists.\n\nDo you want to overwrite it?\n"), fn);
 
@@ -181,7 +178,8 @@ async_xfer_callback (GnomeVFSAsyncHandle *handle,
             && data->prev_status != GNOME_VFS_XFER_PROGRESS_STATUS_OVERWRITE)
         {
             const gchar *error = gnome_vfs_result_to_string (info->vfs_status);
-            gchar *t = gnome_vfs_get_local_path_from_uri (info->target_name);
+            gchar *t = gnome_cmd_dir_is_local (data->to_dir) ? gnome_vfs_get_local_path_from_uri (info->target_name) :
+                                                               str_uri_basename (info->target_name);
             gchar *fn = get_utf8 (t);
             gchar *msg = g_strdup_printf (_("Error while copying to %s\n\n%s"), fn, error);
 
@@ -252,7 +250,7 @@ static gboolean update_xfer_gui_func (XferData *data)
             if ((total_diff > (gfloat)0.01 && total_prog >= 0.0 && total_prog <= 1.0) || data->first_time)
             {
                 data->first_time = FALSE;
-                gnome_cmd_xfer_progress_win_set_total_progress (data->win, data->total_bytes_copied, data->bytes_total);
+                gnome_cmd_xfer_progress_win_set_total_progress (data->win, data->bytes_copied, data->file_size, data->total_bytes_copied, data->bytes_total);
                 while (gtk_events_pending ())
                     gtk_main_iteration_do (FALSE);
             }
@@ -400,7 +398,7 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
 
     gint num_files = g_list_length (src_uri_list);
 
-    if (g_list_length (src_uri_list) == 1 && dest_fn != NULL)
+    if (num_files == 1 && dest_fn != NULL)
     {
         dest_uri = gnome_cmd_dir_get_child_uri (to_dir, dest_fn);
 
@@ -422,7 +420,7 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
 
     g_free (dest_fn);
 
-    data->win = GNOME_CMD_XFER_PROGRESS_WIN (gnome_cmd_xfer_progress_win_new ());
+    data->win = GNOME_CMD_XFER_PROGRESS_WIN (gnome_cmd_xfer_progress_win_new (num_files));
     gtk_widget_ref (GTK_WIDGET (data->win));
     gtk_window_set_title (GTK_WINDOW (data->win), _("preparing..."));
     gtk_widget_show (GTK_WIDGET (data->win));
@@ -506,9 +504,9 @@ gnome_cmd_xfer_tmp_download_multiple (GList *src_uri_list,
 
     data = create_xfer_data (xferOptions, src_uri_list, dest_uri_list,
                              NULL, NULL, NULL,
-                             (GFunc)on_completed_func, on_completed_data);
+                             (GFunc) on_completed_func, on_completed_data);
 
-    data->win = GNOME_CMD_XFER_PROGRESS_WIN (gnome_cmd_xfer_progress_win_new ());
+    data->win = GNOME_CMD_XFER_PROGRESS_WIN (gnome_cmd_xfer_progress_win_new (g_list_length (src_uri_list)));
     gtk_window_set_title (GTK_WINDOW (data->win), _("downloading to /tmp"));
     gtk_widget_show (GTK_WIDGET (data->win));
 
@@ -521,12 +519,10 @@ gnome_cmd_xfer_tmp_download_multiple (GList *src_uri_list,
                                    GNOME_VFS_XFER_ERROR_MODE_ABORT,
                                    xferOverwriteMode,
                                    XFER_PRIORITY,
-                                   (GnomeVFSAsyncXferProgressCallback)async_xfer_callback,
+                                   (GnomeVFSAsyncXferProgressCallback) async_xfer_callback,
                                    data,
                                    xfer_callback,
                                    data);
 
-    g_timeout_add (gnome_cmd_data_get_gui_update_rate (),
-                   (GSourceFunc) update_xfer_gui_func,
-                   data);
+    g_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GSourceFunc) update_xfer_gui_func, data);
 }
