@@ -22,8 +22,6 @@
 
 #include "gnome-cmd-pixmap.h"
 
-G_BEGIN_DECLS
-
 /**
  * If you add a pixmap id here be sure to add its filename in
  * the array in imageloader.c
@@ -36,24 +34,14 @@ typedef enum
     PIXMAP_FLIST_ARROW_DOWN,
     PIXMAP_FLIST_ARROW_BLANK,
 
-    PIXMAP_SERVER_SMALL,
     PIXMAP_LOGO,
-    PIXMAP_EXEC,
     PIXMAP_EXEC_WHEEL,
-    PIXMAP_MKDIR,
-    PIXMAP_LOCK,
-    PIXMAP_HOME,
-    PIXMAP_DESKTOP,
-    PIXMAP_SMB_NETWORK,
-    PIXMAP_SMB_COMPUTER,
     PIXMAP_BOOKMARK,
 
     PIXMAP_OVERLAY_SYMLINK,
     PIXMAP_OVERLAY_UMOUNT,
     PIXMAP_PARENT_DIR,
     PIXMAP_ROOT_DIR,
-    PIXMAP_FTP_CONNECT,
-    PIXMAP_FTP_DISCONNECT,
     PIXMAP_SWITCH_V,
     PIXMAP_SWITCH_H,
 
@@ -79,6 +67,4 @@ gboolean IMAGE_get_pixmap_and_mask (GnomeVFSFileType type,
 
 void IMAGE_clear_mime_cache (void);
 
-G_END_DECLS
-
 #endif // __IMAGELOADER_H__
