@@ -1,37 +1,38 @@
 /*
-  GNOME Commander - A GNOME based file manager
-  Copyright (C) 2001-2006 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
 #include <locale.h>
 #include <errno.h>
 #include <dirent.h>
+
+#include <set>
+
 #include "gnome-cmd-includes.h"
 #include "utils.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-plain-path.h"
 #include "imageloader.h"
 #include "gnome-cmd-main-win.h"
+#include "gnome-cmd-con-list.h"
 #include "gnome-cmd-xfer.h"
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
 #include <fnmatch.h>
 
 using namespace std;
@@ -42,7 +43,6 @@ typedef struct
     GnomeCmdFile *finfo;
     GtkWidget *dialog;
     gpointer *args;
-
 } TmpDlData;
 
 #ifdef HAVE_LOCALE_H
@@ -119,39 +119,45 @@ void run_command_indir (const gchar *in_command, const gchar *dir, gboolean term
 
     if (term)
     {
-        gchar *tmp, *arg;
+        gchar *arg;
+
+        if (gnome_cmd_data_get_use_gcmd_block ())
+        {
+            gchar *s = g_strdup_printf ("%s; %s/bin/gcmd-block", in_command, PREFIX);
+            arg = g_shell_quote (s);
+            g_free (s);
+        }
+        else
+            arg = g_shell_quote (in_command);
 
-        tmp = g_strdup_printf ("%s; %s/bin/gcmd-block", in_command, PREFIX);
-        arg = g_shell_quote (tmp);
         command = g_strdup_printf (gnome_cmd_data_get_term (), arg);
+
         g_free (arg);
-        g_free (tmp);
     }
     else
         command = g_strdup (in_command);
 
-    DEBUG ('g', "running: %s\n", command);
+    DEBUG ('g', "running%s: %s\n", (term?" in terminal":""), command);
+
     gnome_execute_shell (dir, command);
     g_free (command);
 }
 
 
-const char **
-convert_varargs_to_name_array (va_list args)
+const char **convert_varargs_to_name_array (va_list args)
 {
-    GPtrArray *resizeable_array;
     const char *name;
-    const char **plain_ole_array;
 
-    resizeable_array = g_ptr_array_new ();
+    GPtrArray *resizeable_array = g_ptr_array_new ();
 
     do
     {
         name = va_arg (args, const char *);
         g_ptr_array_add (resizeable_array, (gpointer) name);
-    } while (name != NULL);
+    }
+    while (name);
 
-    plain_ole_array = (const char **) resizeable_array->pdata;
+    const char **plain_ole_array = (const char **) resizeable_array->pdata;
 
     g_ptr_array_free (resizeable_array, FALSE);
 
@@ -159,8 +165,7 @@ convert_varargs_to_name_array (va_list args)
 }
 
 
-static gboolean
-delete_event_callback (gpointer data, gpointer user_data)
+static gboolean delete_event_callback (gpointer data, gpointer user_data)
 {
     g_return_val_if_fail (GTK_IS_DIALOG (data), FALSE);
 
@@ -170,8 +175,7 @@ delete_event_callback (gpointer data, gpointer user_data)
 }
 
 
-static gboolean
-on_run_dialog_keypress (GtkWidget *dialog, GdkEventKey *event, gpointer data)
+static gboolean on_run_dialog_keypress (GtkWidget *dialog, GdkEventKey *event, gpointer data)
 {
     if (event->keyval == GDK_Escape)
     {
@@ -183,10 +187,9 @@ on_run_dialog_keypress (GtkWidget *dialog, GdkEventKey *event, gpointer data)
 }
 
 
-gint
-run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
-                   GtkMessageType msg_type,
-                   const char *text, const char *title, gint def_response, ...)
+gint run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
+                        GtkMessageType msg_type,
+                        const char *text, const char *title, gint def_response, ...)
 {
     va_list button_title_args;
     const char **button_titles;
@@ -213,7 +216,7 @@ run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
 
     // Allow close.
     if (ignore_close_box)
-        gtk_signal_connect (GTK_OBJECT (dialog), "delete_event", GTK_SIGNAL_FUNC (delete_event_callback), NULL);
+        gtk_signal_connect (GTK_OBJECT (dialog), "delete-event", GTK_SIGNAL_FUNC (delete_event_callback), NULL);
     else
         gtk_signal_connect (GTK_OBJECT (dialog), "key-press-event", GTK_SIGNAL_FUNC (on_run_dialog_keypress), dialog);
 
@@ -224,7 +227,8 @@ run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
     {
         gtk_widget_show (dialog);
         result = gtk_dialog_run (GTK_DIALOG (dialog));
-    } while (ignore_close_box && result == GTK_RESPONSE_DELETE_EVENT);
+    }
+    while (ignore_close_box && result == GTK_RESPONSE_DELETE_EVENT);
 
     gtk_widget_destroy(dialog);
 
@@ -237,26 +241,23 @@ gchar *str_uri_basename (const gchar *uri)
     if (!uri)
         return NULL;
 
-    int i,
-        len = strlen (uri),
+    int len = strlen (uri),
         last_slash=0;
 
     if (len < 2)
         return NULL;
 
-    for (i=0; i<len; i++)
-    {
+    for (int i=0; i<len; i++)
         if (uri[i] == '/')
             last_slash = i;
-    }
 
     return gnome_vfs_unescape_string (&uri[last_slash+1], NULL);
 }
 
 
-void type2string (GnomeVFSFileType type, gchar *buf, guint max)
+const gchar *type2string (GnomeVFSFileType type, gchar *buf, guint max)
 {
-    char *s;
+    const char *s;
 
     switch (type)
     {
@@ -290,34 +291,36 @@ void type2string (GnomeVFSFileType type, gchar *buf, guint max)
     }
 
     g_snprintf (buf, max, "%s", s);
+
+    return buf;
 }
 
 
-void name2string (gchar *filename, gchar *buf, guint max)
+const gchar *name2string (gchar *filename, gchar *buf, guint max)
 {
     g_snprintf (buf, max, "%s", filename);
+
+    return buf;
 }
 
 
-void perm2string (GnomeVFSFilePermissions p, gchar *buf, guint max)
+const gchar *perm2string (GnomeVFSFilePermissions p, gchar *buf, guint max)
 {
     switch (gnome_cmd_data_get_perm_disp_mode ())
     {
         case GNOME_CMD_PERM_DISP_MODE_TEXT:
-            perm2textstring (p, buf, max);
-            break;
+            return perm2textstring (p, buf, max);
+
         case GNOME_CMD_PERM_DISP_MODE_NUMBER:
-            perm2numstring (p, buf, max);
-            break;
+            return perm2numstring (p, buf, max);
 
         default:
-            perm2textstring (p, buf, max);
-            break;
+            return perm2textstring (p, buf, max);
     }
 }
 
 
-void perm2textstring (GnomeVFSFilePermissions p, gchar *buf, guint max)
+const gchar *perm2textstring (GnomeVFSFilePermissions p, gchar *buf, guint max)
 {
     g_snprintf (buf, max, "%s%s%s%s%s%s%s%s%s",
                 (p & GNOME_VFS_PERM_USER_READ) ? "r" : "-",
@@ -329,10 +332,12 @@ void perm2textstring (GnomeVFSFilePermissions p, gchar *buf, guint max)
                 (p & GNOME_VFS_PERM_OTHER_READ) ? "r" : "-",
                 (p & GNOME_VFS_PERM_OTHER_WRITE) ? "w" : "-",
                 (p & GNOME_VFS_PERM_OTHER_EXEC) ? "x" : "-");
+
+    return buf;
 }
 
 
-void perm2numstring (GnomeVFSFilePermissions p, gchar *buf, guint max)
+const gchar *perm2numstring (GnomeVFSFilePermissions p, gchar *buf, guint max)
 {
     gint i = 0;
 
@@ -347,6 +352,8 @@ void perm2numstring (GnomeVFSFilePermissions p, gchar *buf, guint max)
     if (p & GNOME_VFS_PERM_OTHER_EXEC) i += 1;
 
     g_snprintf (buf, max, "%d", i);
+
+    return buf;
 }
 
 
@@ -355,16 +362,16 @@ const gchar *size2string (GnomeVFSFileSize size, GnomeCmdSizeDispMode size_disp_
     static gchar buf0[64];
     static gchar buf1[128];
 
-    gint i;
 
     switch (size_disp_mode)
     {
         case GNOME_CMD_SIZE_DISP_MODE_POWERED:
             {
-                static gchar *prefixes[] = {"B","kB","MB","GB","TB","PB"};
+                static const gchar *prefixes[] = {"B","kB","MB","GB","TB","PB"};
                 gdouble dsize = (gdouble) size;
+                guint i;
 
-                for (i=0; i<ARRAY_ELEMENTS(prefixes) && dsize>1024; i++)
+                for (i=0; i<G_N_ELEMENTS(prefixes) && dsize>1024; i++)
                     dsize /= 1024;
 
                 if (i)
@@ -388,7 +395,7 @@ const gchar *size2string (GnomeVFSFileSize size, GnomeCmdSizeDispMode size_disp_
 
                 *dest++ = *src++;
 
-                for (i=len; i>0; i--)
+                for (gint i=len; i>0; i--)
                 {
                     if (i>2 && i%3 == 2)
                         dest = g_stpcpy (dest, sep);
@@ -418,6 +425,7 @@ const gchar *time2string (time_t t, const gchar *date_format)
 
     localtime_r (&t, &lt);
     strftime (buf, sizeof(buf), date_format, &lt);
+
     return buf;
 }
 
@@ -426,8 +434,7 @@ inline void no_mime_app_found_error (gchar *mime_type)
 {
     gchar *msg;
 
-    msg = g_strdup_printf (_("No default application found for the mime-type %s.\nOpen the \"File types and programs\" page in the Control Center to add one."),
-                           mime_type);
+    msg = g_strdup_printf (_("No default application found for the MIME type %s.\nOpen the \"File types and programs\" page in the Control Center to add one."), mime_type);
     create_error_dialog (msg);
     g_free (msg);
 }
@@ -435,22 +442,26 @@ inline void no_mime_app_found_error (gchar *mime_type)
 
 static void do_mime_exec_single (gpointer *args)
 {
+    g_return_if_fail (args != NULL);
+
     GnomeCmdApp *app = (GnomeCmdApp *) args[0];
     gchar *path = (gchar *) args[1];
-    gchar *arg = g_shell_quote (path);
-    gchar *cmd = g_strdup_printf ("%s %s", gnome_cmd_app_get_command (app), arg);
+    gchar *dpath = (gchar *) args[2];
+
+    string cmd = gnome_cmd_app_get_command (app);
+    cmd += ' ';
+    cmd += stringify (g_shell_quote (path));
+
+    run_command_indir (cmd.c_str(), dpath, gnome_cmd_app_get_requires_terminal (app));
 
-    g_free (arg);
-    run_command (cmd, gnome_cmd_app_get_requires_terminal (app));
-    g_free (cmd);
     g_free (path);
+    g_free (dpath);
     gnome_cmd_app_free (app);
     g_free (args);
 }
 
 
-static void
-on_tmp_download_response (GtkWidget *w, gint id, TmpDlData *dldata)
+static void on_tmp_download_response (GtkWidget *w, gint id, TmpDlData *dldata)
 {
     if (id == GTK_RESPONSE_YES)
     {
@@ -458,11 +469,11 @@ on_tmp_download_response (GtkWidget *w, gint id, TmpDlData *dldata)
 
         if (!path_str) return;
 
-        dldata->args[1] = (gpointer)path_str;
+        dldata->args[1] = (gpointer) path_str;
 
         GnomeVFSURI *src_uri = gnome_vfs_uri_dup (gnome_cmd_file_get_uri (dldata->finfo));
         GnomeCmdPath *path = gnome_cmd_plain_path_new (path_str);
-        GnomeCmdCon *con = gnome_cmd_con_list_get_home (gnome_cmd_data_get_con_list ());
+        GnomeCmdCon *con = get_home_con ();
         GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (con, path);
         gtk_object_destroy (GTK_OBJECT (path));
 
@@ -486,13 +497,13 @@ on_tmp_download_response (GtkWidget *w, gint id, TmpDlData *dldata)
 
 void mime_exec_single (GnomeCmdFile *finfo)
 {
+    g_return_if_fail (finfo != NULL);
+    g_return_if_fail (finfo->info != NULL);
+
     gpointer *args;
     GnomeVFSMimeApplication *vfs_app;
     GnomeCmdApp *app;
 
-    g_return_if_fail (finfo != NULL);
-    g_return_if_fail (finfo->info != NULL);
-
     if (!finfo->info->mime_type)
         return;
 
@@ -500,21 +511,20 @@ void mime_exec_single (GnomeCmdFile *finfo)
 
     if (!gnome_cmd_file_is_executable (finfo))
     {
-        if (gnome_cmd_file_has_mime_type (finfo, "application/x-executable-binary"))
+        if (gnome_cmd_file_has_mime_type (finfo, "application/x-executable") || gnome_cmd_file_has_mime_type (finfo, "application/x-executable-binary"))
         {
             gchar *fname = get_utf8 (finfo->info->name);
             gchar *msg = g_strdup_printf (_("\"%s\" seems to be a binary executable file but it lacks the executable bit. Do you want to set it and then run the file?"), fname);
-            gint ret = run_simple_dialog (
-                GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_QUESTION, msg,
-                _("Make Executable?"),
-                -1, _("Cancel"), _("OK"), NULL);
+            gint ret = run_simple_dialog (GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_QUESTION, msg,
+                                          _("Make Executable?"),
+                                          -1, _("Cancel"), _("OK"), NULL);
             g_free (fname);
             g_free (msg);
 
             if (ret != 1)  return;  else
             {
-                GnomeVFSResult res = gnome_cmd_file_chmod (finfo, (GnomeVFSFilePermissions) (finfo->info->permissions|GNOME_VFS_PERM_USER_EXEC));
-                if (res != GNOME_VFS_OK)
+                GnomeVFSResult result = gnome_cmd_file_chmod (finfo, (GnomeVFSFilePermissions) (finfo->info->permissions|GNOME_VFS_PERM_USER_EXEC));
+                if (result != GNOME_VFS_OK)
                     return;
             }
         }
@@ -524,7 +534,7 @@ void mime_exec_single (GnomeCmdFile *finfo)
 
     if (gnome_cmd_file_is_executable (finfo))
     {
-        if (gnome_cmd_file_has_mime_type (finfo, "application/x-executable-binary"))
+        if (gnome_cmd_file_has_mime_type (finfo, "application/x-executable") || gnome_cmd_file_has_mime_type (finfo, "application/x-executable-binary") )
         {
             gnome_cmd_file_execute (finfo);
             return;
@@ -534,9 +544,8 @@ void mime_exec_single (GnomeCmdFile *finfo)
             {
                 gchar *fname = get_utf8 (finfo->info->name);
                 gchar *msg = g_strdup_printf (_("\"%s\" is an executable text file. Do you want to run it, or display its contents?"), fname);
-                gint ret = run_simple_dialog (
-                    GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_QUESTION, msg, _("Run or Display"),
-                    -1, _("Cancel"), _("Display"), _("Run"), NULL);
+                gint ret = run_simple_dialog (GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_QUESTION, msg, _("Run or Display"),
+                                              -1, _("Cancel"), _("Display"), _("Run"), NULL);
                 g_free (fname);
                 g_free (msg);
 
@@ -559,31 +568,32 @@ void mime_exec_single (GnomeCmdFile *finfo)
     app = gnome_cmd_app_new_from_vfs_app (vfs_app);
     gnome_vfs_mime_application_free (vfs_app);
 
-    args = g_new0 (gpointer, 2);
+    args = g_new0 (gpointer, 3);
 
     if (gnome_cmd_file_is_local (finfo))
     {
-        args[0] = (gpointer)app;
-        args[1] = (gpointer)g_strdup (gnome_cmd_file_get_real_path (finfo));
+        args[0] = (gpointer) app;
+        args[1] = (gpointer) g_strdup (gnome_cmd_file_get_real_path (finfo));
+        args[2] = (gpointer) g_path_get_dirname ((gchar *) args[1]);            // set exec dir for local files
         do_mime_exec_single (args);
     }
     else
     {
-        if (gnome_cmd_app_get_handles_uris (app)
-            && gnome_cmd_data_get_honor_expect_uris())
+        if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data_get_honor_expect_uris())
         {
-            args[0] = (gpointer)app;
-            args[1] = (gpointer)g_strdup (gnome_cmd_file_get_uri_str (finfo));
+            args[0] = (gpointer) app;
+            args[1] = (gpointer) g_strdup (gnome_cmd_file_get_uri_str (finfo));
+            // args[2] is NULL here (don't set exec dir for remote files)
             do_mime_exec_single (args);
         }
         else
         {
             gchar *msg = g_strdup_printf (_("%s does not know how to open remote file. Do you want to download the file to a temporary location and then open it?"), gnome_cmd_app_get_name (app));
-            GtkWidget *dialog = gtk_message_dialog_new (
-                GTK_WINDOW (main_win), GTK_DIALOG_MODAL,
-                GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, msg);
+            GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW (main_win), GTK_DIALOG_MODAL,
+                                                        GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, msg);
             TmpDlData *dldata = g_new0 (TmpDlData, 1);
-            args[0] = (gpointer)app;
+            args[0] = (gpointer) app;
+            // args[2] is NULL here (don't set exec dir for temporarily downloaded files)
             dldata->finfo = finfo;
             dldata->dialog = dialog;
             dldata->args = args;
@@ -603,23 +613,29 @@ static void do_mime_exec_multiple (gpointer *args)
 
     if (files)
     {
-        gchar *cmd = g_strdup_printf ("%s ", gnome_cmd_app_get_command (app));
+        string cmd = gnome_cmd_app_get_command (app);
+
+        set<string> dirs;
 
         for (; files; files = files->next)
         {
-            gchar *path = (gchar *) files->data;
-            gchar *tmp = cmd;
-            gchar *arg = g_shell_quote (path);
-            cmd = g_strdup_printf ("%s %s", tmp, arg);
-            g_free (arg);
-            g_free (path);
-            g_free (tmp);
+            cmd += ' ';
+            cmd += stringify (g_shell_quote ((gchar *) files->data));
+
+            gchar *dpath = g_path_get_dirname ((gchar *) files->data);
+
+            if (dpath)
+                dirs.insert (stringify (dpath));
         }
 
-        run_command (cmd, gnome_cmd_app_get_requires_terminal (app));
-        g_free (cmd);
+        if (dirs.size()==1)
+            run_command_indir (cmd.c_str(), dirs.begin()->c_str(), gnome_cmd_app_get_requires_terminal (app));
+        else
+            run_command (cmd.c_str(), gnome_cmd_app_get_requires_terminal (app));
+
         g_list_free (files);
     }
+
     gnome_cmd_app_free (app);
     g_free (args);
 }
@@ -661,7 +677,7 @@ void mime_exec_multiple (GList *files, GnomeCmdApp *app)
                     asked = TRUE;
                 }
 
-                if (retid == 1)
+                if (retid==1)
                 {
                     gchar *path_str = get_temp_download_filepath (gnome_cmd_file_get_name (finfo));
 
@@ -669,8 +685,7 @@ void mime_exec_multiple (GList *files, GnomeCmdApp *app)
 
                     GnomeVFSURI *src_uri = gnome_vfs_uri_dup (gnome_cmd_file_get_uri (finfo));
                     GnomeCmdPath *path = gnome_cmd_plain_path_new (path_str);
-                    GnomeCmdCon *con = gnome_cmd_con_list_get_home (gnome_cmd_data_get_con_list ());
-                    GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (con, path);
+                    GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (get_home_con (), path);
                     gtk_object_destroy (GTK_OBJECT (path));
 
                     src_uri_list = g_list_append (src_uri_list, src_uri);
@@ -688,15 +703,12 @@ void mime_exec_multiple (GList *files, GnomeCmdApp *app)
     args[1] = local_files;
 
     if (src_uri_list)
-    {
-        gnome_cmd_xfer_tmp_download_multiple (
-            src_uri_list,
-            dest_uri_list,
-            GNOME_VFS_XFER_FOLLOW_LINKS,
-            GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-            GTK_SIGNAL_FUNC (do_mime_exec_multiple),
-            args);
-    }
+        gnome_cmd_xfer_tmp_download_multiple (src_uri_list,
+                                              dest_uri_list,
+                                              GNOME_VFS_XFER_FOLLOW_LINKS,
+                                              GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+                                              GTK_SIGNAL_FUNC (do_mime_exec_multiple),
+                                              args);
     else
         do_mime_exec_multiple (args);
 }
@@ -715,8 +727,7 @@ void clear_event_key (GdkEventKey *event)
 /**
  * Transform a "\r\n" separated string into a GList with GnomeVFSURI's
  */
-GList *
-strings_to_uris (gchar *data)
+GList *strings_to_uris (gchar *data)
 {
     GList *uri_list = NULL;
     gchar **filenames = g_strsplit (data, "\r\n", STRINGS_TO_URIS_CHUNK);
@@ -750,11 +761,13 @@ GnomeVFSFileSize calc_tree_size (const GnomeVFSURI *dir_uri)
     gchar *dir_uri_str;
     GnomeVFSResult result;
 
-    if (!dir_uri) return -1;
+    if (!dir_uri)
+        return -1;
 
     dir_uri_str = gnome_vfs_uri_to_string (dir_uri, GNOME_VFS_URI_HIDE_NONE);
 
-    if (!dir_uri_str) return -1;
+    if (!dir_uri_str)
+        return -1;
 
     result = gnome_vfs_directory_list_load (&list, dir_uri_str, infoOpts);
 
@@ -790,7 +803,7 @@ GnomeVFSFileSize calc_tree_size (const GnomeVFSURI *dir_uri)
 }
 
 
-GList *string_history_add (GList *in, const gchar *value, gint maxsize)
+GList *string_history_add (GList *in, const gchar *value, guint maxsize)
 {
     GList *tmp = g_list_find_custom (in, (gchar *) value, (GCompareFunc)strcmp);
     GList *out;
@@ -820,8 +833,7 @@ GList *string_history_add (GList *in, const gchar *value, gint maxsize)
 }
 
 
-const gchar *
-create_nice_size_str (GnomeVFSFileSize size)
+const gchar *create_nice_size_str (GnomeVFSFileSize size)
 {
     static gchar str1[64];
     const gchar *s1 = size2string (size, GNOME_CMD_SIZE_DISP_MODE_GROUPED);
@@ -953,22 +965,21 @@ void set_cursor_default (void)
 
 GList *app_get_linked_libs (GnomeCmdFile *finfo)
 {
-    FILE *fd;
-    gchar *cmd, *s;
-    gchar tmp[256];
-    gchar *arg;
-    GList *libs = NULL;
-
     g_return_val_if_fail (GNOME_CMD_IS_FILE (finfo), NULL);
 
-    arg = g_shell_quote (gnome_cmd_file_get_real_path (finfo));
-    cmd = g_strdup_printf ("ldd %s", arg);
+    gchar *s;
+    gchar tmp[256];
+
+    gchar *arg = g_shell_quote (gnome_cmd_file_get_real_path (finfo));
+    gchar *cmd = g_strdup_printf ("ldd %s", arg);
     g_free (arg);
-    fd = popen (cmd, "r");
+    FILE *fd = popen (cmd, "r");
     g_free (cmd);
 
     if (!fd) return NULL;
 
+    GList *libs = NULL;
+
     while ((s = fgets (tmp, sizeof(tmp), fd)))
     {
         char **v = g_strsplit (s, " ", 1);
@@ -987,8 +998,8 @@ gboolean app_needs_terminal (GnomeCmdFile *finfo)
 {
     gboolean need_term = TRUE;
 
-    if (strcmp (finfo->info->mime_type, "application/x-executable-binary"))
-        return TRUE;
+    if (strcmp (finfo->info->mime_type, "application/x-executable") && strcmp (finfo->info->mime_type, "application/x-executable-binary"))
+        return need_term;
 
     GList *libs = app_get_linked_libs (finfo);
     if  (!libs) return FALSE;
@@ -997,14 +1008,14 @@ gboolean app_needs_terminal (GnomeCmdFile *finfo)
     {
         gchar *lib = (gchar *) tmp->data;
         lib = g_strstrip (lib);
-        if (strncmp (lib, "libX11", 6) == 0)
+        if (g_str_has_prefix (lib, "libX11"))
         {
             need_term = FALSE;
             break;
         }
     }
 
-    g_list_foreach (libs, (GFunc)g_free, NULL);
+    g_list_foreach (libs, (GFunc) g_free, NULL);
     g_list_free (libs);
 
     return need_term;
@@ -1050,11 +1061,35 @@ void remove_temp_download_dir (void)
 }
 
 
-GtkWidget *
-create_ui_pixmap (GtkWidget *window,
-                  GnomeUIPixmapType pixmap_type,
-                  gconstpointer pixmap_info,
-                  GtkIconSize size)
+inline GtkWidget *scale_pixbuf (GdkPixbuf *pixbuf, GtkIconSize icon_size)
+{
+    int width, height;
+
+    gtk_icon_size_lookup (icon_size, &width, &height);
+
+    double pix_x = gdk_pixbuf_get_width (pixbuf);
+    double pix_y = gdk_pixbuf_get_height (pixbuf);
+
+    // Only scale if the image doesn't match the required icon size
+    if (pix_x > width || pix_y > height)
+    {
+        double greatest = pix_x > pix_y ? pix_x : pix_y;
+        GdkPixbuf *scaled = gdk_pixbuf_scale_simple (pixbuf,
+                                                     (width/ greatest) * pix_x,
+                                                     (height/ greatest) * pix_y,
+                                                      GDK_INTERP_BILINEAR);
+        GtkWidget *image = gtk_image_new_from_pixbuf (scaled);
+        g_object_unref (G_OBJECT (scaled));
+
+        return image;
+    }
+
+    return gtk_image_new_from_pixbuf (pixbuf);
+}
+
+// Creates a pixmap appropriate for items
+
+GtkWidget *create_ui_pixmap (GtkWidget *unused, GnomeUIPixmapType pixmap_type, gconstpointer pixmap_info, GtkIconSize icon_size)
 {
     GtkWidget *pixmap = NULL;
     char *name;
@@ -1062,28 +1097,37 @@ create_ui_pixmap (GtkWidget *window,
     switch (pixmap_type)
     {
         case GNOME_APP_PIXMAP_STOCK:
-            pixmap = gtk_image_new_from_stock ((const gchar *) pixmap_info, size);
+            pixmap = gtk_image_new_from_stock (static_cast<const gchar *>(pixmap_info), icon_size);
             break;
 
         case GNOME_APP_PIXMAP_DATA:
             if (pixmap_info)
-                pixmap = gnome_pixmap_new_from_xpm_d ((const char **) pixmap_info);
+            {
+                GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data ((const char **) pixmap_info);
+                if (pixbuf != NULL)
+                {
+                    pixmap = scale_pixbuf (pixbuf, icon_size);
+                    g_object_unref (G_OBJECT (pixbuf));
+                }
+            }
             break;
 
         case GNOME_APP_PIXMAP_NONE:
             break;
 
         case GNOME_APP_PIXMAP_FILENAME:
-            name = gnome_pixmap_file ((const gchar *) pixmap_info);
+            name = gnome_program_locate_file (gnome_program_get (), GNOME_FILE_DOMAIN_APP_PIXMAP,
+                                              static_cast<const gchar *>(pixmap_info), TRUE, NULL);
 
             if (!name)
-                g_warning ("GNOME pixmap file %s cannot be found", (char *) pixmap_info);
+                g_warning ("Could not find GNOME pixmap file %s", (char *) pixmap_info);
             else
             {
-                pixmap = gnome_pixmap_new_from_file (name);
+                GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file (name, NULL);
+                pixmap = scale_pixbuf (pixbuf, icon_size);
+                g_object_unref (G_OBJECT (pixbuf));
                 g_free (name);
             }
-
             break;
 
         default:
@@ -1095,13 +1139,13 @@ create_ui_pixmap (GtkWidget *window,
 }
 
 
-static void
-transform (gchar *s, gchar from, gchar to)
+inline void transform (gchar *s, gchar from, gchar to)
 {
     gint len = strlen (s);
 
     for (gint i=0; i<len; i++)
-        if (s[i] == from) s[i] = to;
+        if (s[i] == from)
+            s[i] = to;
 }
 
 
@@ -1178,8 +1222,7 @@ GList *file_list_to_info_list (GList *files)
 }
 
 
-gboolean
-create_dir_if_needed (const gchar *dpath)
+gboolean create_dir_if_needed (const gchar *dpath)
 {
     g_return_val_if_fail (dpath, FALSE);
 
@@ -1208,8 +1251,7 @@ create_dir_if_needed (const gchar *dpath)
 }
 
 
-void
-edit_mimetypes (const gchar *mime_type, gboolean blocking)
+void edit_mimetypes (const gchar *mime_type, gboolean blocking)
 {
     if (!mime_type)
         mime_type = "";
@@ -1283,38 +1325,44 @@ void patlist_free (GList *pattern_list)
 gboolean patlist_matches (GList *pattern_list, const gchar *s)
 {
     for (GList *tmp = pattern_list; tmp; tmp = tmp->next)
+#ifdef FNM_CASEFOLD
         if (fnmatch ((gchar *) tmp->data, s, FNM_NOESCAPE|FNM_CASEFOLD) == 0)
+#else
+        if (fnmatch ((gchar *) tmp->data, s, FNM_NOESCAPE) == 0)   // omit FNM_CASEFOLD as it is a GNU extension.
+#endif
             return TRUE;
 
     return FALSE;
 }
 
 
-void gnome_cmd_error_message(const gchar *title, GError *error)
+int split(const string &s, vector<string> &coll, const char *sep)
 {
-    GtkWidget *dialog = gtk_message_dialog_new (NULL,
-                                                GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_CLOSE,
-                                                title);
+  coll.clear();
 
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), error->message);
+  if (s.empty())  return 0;
 
-    g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (gtk_widget_destroy), NULL);
+  if (!sep)  sep = "";
+  int seplen = strlen(sep);
 
-    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-    gtk_widget_show (dialog);
+  if (!seplen)
+  {
+    for (string::const_iterator i=s.begin(); i!=s.end(); ++i)
+      coll.push_back(string(1,*i));
 
-    g_error_free (error);
-}
+    return s.length();
+  }
 
+  int n = 1;
+  int start = 0;
 
-void gnome_cmd_help_display(const gchar *file_name, const gchar *link_id)
-{
-    GError *error = NULL;
+  for (int end; (end=s.find(sep,start))!=string::npos; ++n)
+  {
+    coll.push_back(string(s,start,end-start));
+    start = end + seplen;
+  }
 
-    gnome_help_display (file_name, link_id, &error);
+  coll.push_back(string(s,start));
 
-    if (error != NULL)
-        gnome_cmd_error_message(_("There was an error displaying help."), error);
+  return n;
 }
